#ifndef RADIOAPI_HPP
#define RADIOAPI_HPP

/*
 *
 * Radio API source module for PCnet-MOBILE 802.11 protocol firmware.
 *
 * Copyright (c) 1996, 1997, 1998 Advanced Micro Devices, Inc.
 * All rights reserved.
 *
 * Version 2.0
 *
 * Controller & Switch Development (CSD)
 *
 * Module Name: radioapi.hpp
 *
 * Globals Accessed:
 *
 * Callers:
 *
 * Called routines:
 *
 * Functional Description:
 *
 * Comments:
 *
 * Diagnostics:
 *
 */

#define kcSynthElements 15    // Elements in the frequency synthesier table

#define TIR2_SDCP 0x008
#define TIR2_SDC 0x004
#define TIR2_SDDT 0x002
#define TIR8_DR 0x08
#define TIR8_ENCRCTX 0x10
#define TIR8_DMASEL 0x20
#define TIR29_USERDT7L 0x080
#define TIR29_USERDT4 0x010
#define TIR29_USERDT0 0x001

#define BPSK_SIGNAL 0x0A
#define QPSK_SIGNAL 0x14
#define DS_PLCP_SERVICE 0x00

//#define COAX            // Configured for coax connection (test mode)
//#define FORCE_QPSK        // Configured for 2 Mbps only (test mode)
#define HARDWARE_DEBUG_PIN    // Enables a USER pin as a debug test output
//#define DEFAULT_DEBUG_CHANNEL 12    // Enabled, always tunes to this
                          // RF channel; else follows core
                          // firmware channel tuning commands



// #define IMAX            //  Defines ISA PCNet Mobile and Prism Chipset
                    //  For PCMCIA configuration 'undefine' IMAX
                              //     I.E.   //#define IMAX

#ifdef COAX
#undef FORCE_QPSK
#undef DEFAULT_DEBUG_CHANNEL
#endif

// *****RJT*****BEGIN TEST CODE*****
// Debug macros write values out to (80188) memory location 0x430 (XCE[0])
#define RJT_Debug_Writeb(byteval) \
    MIR[0x10] = byteval;
#define RJT_Debug_Writew(wordval) \
    MIR[0x10] = ((Unsigned8*)(&wordval))[0]; \
    MIR[0x11] = ((Unsigned8*)(&wordval))[1];

#ifdef HARDWARE_DEBUG_PIN
// Generate active LOW pulse on USER0 pin
#define Pulse_RJT_Debug \
    TIR[USER_PIN_DATA] &= 0xFE; \
    TIR[USER_PIN_DATA] |= 0x01;
// Force USER0 pin LOW
#define Assert_RJT_Debug \
    TIR[USER_PIN_DATA] &= 0xFE;
// Force USER0 pin HIGH
#define Deassert_RJT_Debug \
    TIR[USER_PIN_DATA] |= 0x01;
#endif  // HARDWARE_DEBUG_PIN

// *****RJT*****END TEST CODE*****

// The following two macro definitions generate a byte-by-byte CRC-16
// value when the string of bytes is known at compile time. This is the
// case in a DSSS PLCP, where the first two bytes of the PLCP are determined
// solely by the TX data rate. This relieves us from having to recompute
// the (constant) CRC of the first two PLCP bytes at runtime, leaving us with
// the job of computing the CRC-16 based upon the PLCP length field only.
//
// The parameter c is the running CRC-16 value (before 1's complement). The
// initial value of c is defined by CCITT to be 0xFFFF.
//
// The parameter b is a byte in the CRC-16 protected fields.
//
// The parameter bitnum is an intermediate macro parameter.
//
// This macro may be nested. However, the 'deepest' macro should have a
// parameter c value of 0xFFFF. Example for a BPSK (1Mbps) DS PLCP is:
//   CRC16_MACRO((CRC16_MACRO(0xFFFF,0x0A)),0x00)

#define bit_index(c,b,bitnum) (((c>>(bitnum))&0x0001) ^ ((b>>bitnum)&0x01))

#define CRC16_MACRO(c,b) \
  ((bit_index(c,b,7) ^ bit_index(c,b,3)) ? 0x8000 : 0) | \
  ((bit_index(c,b,2) ^ bit_index(c,b,6)) ? 0x4000 : 0) | \
  ((bit_index(c,b,1) ^ bit_index(c,b,5)) ? 0x2000 : 0) | \
  ((bit_index(c,b,0) ^ bit_index(c,b,4)) ? 0x1000 : 0) | \
  ( bit_index(c,b,3) ? 0x0800 : 0) | \
  ((bit_index(c,b,2) ^ bit_index(c,b,3) ^ bit_index(c,b,7)) ? 0x0400 : 0) | \
  ((bit_index(c,b,1) ^ bit_index(c,b,2) ^ bit_index(c,b,6)) ? 0x0200 : 0) | \
  ((bit_index(c,b,0) ^ bit_index(c,b,1) ^ bit_index(c,b,5)) ? 0x0100 : 0) | \
  ((bit_index(c,b,0) ^ bit_index(c,b,4)) ? ((~(c>>8))&0x0080) : (0x8000&c)>>8) | \
  ( bit_index(c,b,3) ? ((~(c>>8))&0x0040) : (0x4000&c)>>8) | \
  ( bit_index(c,b,2) ? ((~(c>>8))&0x0020) : (0x2000&c)>>8) | \
  ( bit_index(c,b,1) ? ((~(c>>8))&0x0010) : (0x1000&c)>>8) | \
  ((bit_index(c,b,0) ^ bit_index(c,b,3) ^ bit_index(c,b,7)) ? ((~(c>>8))&0x0008) : (0x0800&c)>>8) | \
  ((bit_index(c,b,2) ^ bit_index(c,b,6)) ? ((~(c>>8))&0x0004) : (0x0400&c)>>8) | \
  ((bit_index(c,b,1) ^ bit_index(c,b,5)) ? ((~(c>>8))&0x0002) : (0x0200&c)>>8) | \
  ((bit_index(c,b,0) ^ bit_index(c,b,4)) ? ((~(c>>8))&0x0001) : (0x0100&c)>>8)

// The following macro definition creates a table element used for
// writing to (and verifying) a CR register in the HSP3824. Each
// element is composed of five bytes: bytes 0&1 are TIR3 type values
// for the CR register address, bytes 2&3 are TIR3 type values for
// the CR register write data, and byte 4 is the raw intended write data.
// This macro is used in the definition of the table astH3824_Init_Table[]
// in the function Radio_API_Module::initialize().
//
#define H3824WElmt(RegNum,RegData) \
    ((RegNum & 0x20) ? 0x01 : 0x00) | \
    ((RegNum & 0x10) ? 0x02 : 0x00) | \
    ((RegNum & 0x08) ? 0x04 : 0x00) | \
    ((RegNum & 0x04) ? 0x08 : 0x00) | \
    ((RegNum & 0x02) ? 0x10 : 0x00) | \
    0xA0,\
    ((RegNum & 0x01) ? 0x01 : 0x00) | \
    0x60,\
   ((RegData & 0x80) ? 0x01 : 0x00) | \
    ((RegData & 0x40) ? 0x02 : 0x00) | \
    ((RegData & 0x20) ? 0x04 : 0x00) | \
    ((RegData & 0x10) ? 0x08 : 0x00) | \
    0x80,\
    ((RegData & 0x08) ? 0x01 : 0x00) | \
    ((RegData & 0x04) ? 0x02 : 0x00) | \
    ((RegData & 0x02) ? 0x04 : 0x00) | \
    ((RegData & 0x01) ? 0x08 : 0x00) | \
    0x80, \
    RegData

// The following macro definition returns a word value which represents
// the first two bytes in the current H3824WElmt entry.
// This macro is used in the function initialize_3824().
//
#define H3824address(RegNum) \
   (((RegNum & 0x20) ? 0x01 : 0x00) | \
    ((RegNum & 0x10) ? 0x02 : 0x00) | \
    ((RegNum & 0x08) ? 0x04 : 0x00) | \
    ((RegNum & 0x04) ? 0x08 : 0x00) | \
    ((RegNum & 0x02) ? 0x10 : 0x00) | \
    0xA0 | \
   ((RegNum & 0x01) ? 0x0100 : 0x0000) | \
   0x6000)

/*
;* ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Harris Radio Synthesizer Word Format HFA3524 Dual Frequency Synthesizer
; N and R Counter Formats (shifted left bit (MSBit) first)
;+-----------------------------------------------------------------------+
;|                           IF R - Counter                              |
;+----------------+----------------------------------------------+-------+
;| Program Modes  | msb            Divide Ratio             lsb  | C2 C1 |
;+----------------+----------------------------------------------+-------+
;| 01 02 03 04 05 | 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 | 21 22 |
;+----------------+----------------------------------------------+-------+
;|  x  x  x  x  x |  x  x  x  x  x  x  x  x  x  x  x  x  x  x  x |  0  0 |
;+----------------+----------------------------------------------+-------+
;
;+-------------------------------------------------------------------------+
;|                             IF N - Counter                              |
;+-------+----------------------------------+----------------------+-------+
;| PGM   | msb       DivRatioB          lsb | msb   DivRatioA  lsb | C2 C1 |
;+-------+----------------------------------+----------------------+-------+
;| 01 02 | 03 04 05 06 07 08 09 10 11 12 13 | 14 15 16 17 18 19 20 | 21 22 |
;+-------+----------------------------------+----------------------+-------+
;|  x  x |  x  x  x  x  x  x  x  x  x  x  x |  x  x  x  x  x  x  x |  0  1 |
;+-------+----------------------------------+----------------------+-------+
;
;+-----------------------------------------------------------------------+
;|                           RF R - Counter                              |
;+----------------+----------------------------------------------+-------+
;| Program Modes  | msb            Divide Ratio             lsb  | C2 C1 |
;+----------------+----------------------------------------------+-------+
;| 01 02 03 04 05 | 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 | 21 22 |
;+----------------+----------------------------------------------+-------+
;|  x  x  x  x  x |  x  x  x  x  x  x  x  x  x  x  x  x  x  x  x |  1  0 |
;+----------------+----------------------------------------------+-------+
;
;+-------------------------------------------------------------------------+
;|                             RF N - Counter                              |
;+-------+----------------------------------+----------------------+-------+
;| PGM   | msb       DivRatioB          lsb | msb   DivRatioA  lsb | C2 C1 |
;+-------+----------------------------------+----------------------+-------+
;| 01 02 | 03 04 05 06 07 08 09 10 11 12 13 | 14 15 16 17 18 19 20 | 21 22 |
;+-------+----------------------------------+----------------------+-------+
;|  x  x |  x  x  x  x  x  x  x  x  x  x  x |  x  x  x  x  x  x  x |  1  1 |
;+-------+----------------------------------+----------------------+-------+
;
;TIR3:  Fast Serial Port Control
;
; bit 7:5 BCNT[2:0] Byte count.  From 1 to 5 bits of the FSD[4:0] data may be
; sent during one fast access to the serial port.  The value of BCNT[2:0]
; determines exactly how many bits will be sent for any access.  The value
; BCNT[2:0] = 1 represent a value of one bit to be sent.
;
; bit 4:0 FSD[4:0] Fast Serial Data.  This is the data that is sent out
; during the Fast Serial Port access.  Bit 0 is sent first.  FSD bit values
; are exclusive OR'd XOR with the value written to SDD bit of TIR2[0] before
; being sent to the SDDATA pin.

; The data for the synthesizer needs to be shipped out msb first but since
; the TIR3 register sends the data out lsb first the information in the
; table will be formatted accordingly.  Furthermore, in order to minimize
; the overhead of programming the synthesizer using the TIR3 register the
; table will also include the byte count information embedded as well.
; For example channel #2 for the DSSS PHY is 2.417 GHz.  For this frequency,
; the Program Modes bits (N19.N20) are 00b, the RF N divide ratio B is 66,
; the N divide ratio A is 25 and the Control Bits (C1.C2) are 11b.
; (The IF-R, IF-N, and RF-R values are the same for all channels.)
;
; The formats of the initialization macros are as follows:
;
; macPLLNElmt PGM(N19.N20), DivRatioB(N18..N8), DivRatioA(N7..N1), CTRL(C1.C2)
; macPLLRElmt PGM(R16..R20), DivRatio(R15..R1), CTRL(C1.C2)
;
; PGM bits, CTRL bits, and the various DivRatios are derived from the
; HFA3524 Dual Frequency Synthesizer datasheet.
;
; For example,
; for Channel 2, the four PLL counter elements would look like this:
;
;    macPLLRElmt  24, 22, 0          ; IF R for all channels
;    macPLLNElmt  2, 35, 0, 2          ; IF N for all channels
;    macPLLRElmt  24, 22, 1          ; RF R for all channels
;    macPLLNElmt  0, 66, 25, 3            ; RF N for chnl # 02
;
;+-------------------------------------------------------------+-------+
;| msb                   RF N - Counter                    lsb | CTRL  |
;+-------------------------------------------------------------+-------+
;| 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 | 21 22 |
;+-------------------------------------------------------------+-------+
;|  0  0  0  0  0  0  1  0  0  0  0  1  0  0  0  1  0  1  0  0 |  1  1 |
;+-------------------------------------------------------------+-------+
;
; It will take 5 accesses to TIR3 in order to program this number of bits to
; the synthesizer.  The table will be formatted so that each byte will be
; a combination of data and count.  Thus the element of table for this entry
; (RF N counter) would be:
; count    bit  5 4 3 2 1   synth   program bit
; -----         ---------           --------------
; 1 0 1         0 0 0 0 0           05 04 03 02 01      =   a0
; 1 0 1         0 0 0 1 0           10 09 08 07 06      =   a2
; 1 0 1         0 0 0 1 0           15 14 13 12 11      =   a2
; 1 0 1         0 0 1 0 1           20 19 18 17 16      =   a5
; 0 1 0         x x x 1 1                    22 21      =   43
;
; note: all x's in this table will be set to 0
;
*/

// macro PLLRElmt PGM(R16..R20), DivRatio(R15..R1), CTRL(C1.C2)
#define PLLRElmt(PGMval, DivRatio, CTRLval) \
   PGMval | \
   0xA0,\
   ((DivRatio & 0x4000) ? 0x01 : 0x00) | \
   ((DivRatio & 0x2000) ? 0x02 : 0x00) | \
   ((DivRatio & 0x1000) ? 0x04 : 0x00) | \
   ((DivRatio & 0x0800) ? 0x08 : 0x00) | \
   ((DivRatio & 0x0400) ? 0x10 : 0x00) | \
   0xA0,\
   ((DivRatio & 0x0200) ? 0x01 : 0x00) | \
   ((DivRatio & 0x0100) ? 0x02 : 0x00) | \
   ((DivRatio & 0x0080) ? 0x04 : 0x00) | \
   ((DivRatio & 0x0040) ? 0x08 : 0x00) | \
   ((DivRatio & 0x0020) ? 0x10 : 0x00) | \
   0xA0,\
   ((DivRatio & 0x0010) ? 0x01 : 0x00) | \
   ((DivRatio & 0x0008) ? 0x02 : 0x00) | \
   ((DivRatio & 0x0004) ? 0x04 : 0x00) | \
   ((DivRatio & 0x0002) ? 0x08 : 0x00) | \
   ((DivRatio & 0x0001) ? 0x10 : 0x00) | \
   0xA0,\
   CTRLval | \
   0x40

// macro PLLNElmt PGM(N19.N20), DivRatioB(N18..N8), DivRatioA(N7..N1), CTRL(C1.C2)
#define PLLNElmt(PGMval, DivRatioB, DivRatioA, CTRLval) \
   PGMval | \
   ((DivRatioB & 0x400) ? 0x04 : 0x00) | \
   ((DivRatioB & 0x200) ? 0x08 : 0x00) | \
   ((DivRatioB & 0x100) ? 0x10 : 0x00) | \
   0xA0,\
   ((DivRatioB & 0x80) ? 0x01 : 0x00) | \
   ((DivRatioB & 0x40) ? 0x02 : 0x00) | \
   ((DivRatioB & 0x20) ? 0x04 : 0x00) | \
   ((DivRatioB & 0x10) ? 0x08 : 0x00) | \
   ((DivRatioB & 0x08) ? 0x10 : 0x00) | \
   0xA0,\
   ((DivRatioB & 0x04) ? 0x01 : 0x00) | \
   ((DivRatioB & 0x02) ? 0x02 : 0x00) | \
   ((DivRatioB & 0x01) ? 0x04 : 0x00) | \
   ((DivRatioA & 0x40) ? 0x08 : 0x00) | \
   ((DivRatioA & 0x20) ? 0x10 : 0x00) | \
   0xA0,\
   ((DivRatioA & 0x10) ? 0x01 : 0x00) | \
   ((DivRatioA & 0x08) ? 0x02 : 0x00) | \
   ((DivRatioA & 0x04) ? 0x04 : 0x00) | \
   ((DivRatioA & 0x02) ? 0x08 : 0x00) | \
   ((DivRatioA & 0x01) ? 0x10 : 0x00) | \
   0xA0,\
   CTRLval | \
   0x40

/*****************************************************************************
 *      Usr_Function Bit Defintions
 *
 *   AP   SCAN  MODE STATE
 *   0     0     0     0    -  LNK LED Off
 *   0     0     0     1    -  AD_HOC Synced - LNK LED blips once a second
 *   0     0     1     0    -  LNK LED Off
 *   0     0     1     1    -  Infra station Associated  -  LNK LED on
 *   0     1     0     0    -  Scanning  -  LNK LED fast flash
 *   0     1     0     1    -  Scanning  -  LNK LED fast flash
 *   0     1     1     0    -  Scanning  -  LNK LED fast flash
 *   0     1     1     1    -  Scanning  -  LNK LED fast flash
 *   1     0     0     0    -  AP - No Associations
 *   1     0     0     1    -  AP - At least one association
 *   1     0     1     0    -  AP - No Associations
 *   1     0     1     1    -  AP - at least one association
 *   1     1     0     0    -  Scanning  -  LNK LED fast flash
 *   1     1     0     1    -  Scanning  -  LNK LED fast flash
 *   1     1     1     0    -  Scanning  -  LNK LED fast flash
 *   1     1     1     1    -  Scanning  -  LNK LED fast flash
 ****************************************************************************/

static const Unsigned8 STATE_BIT                                 = 0x01;
static const Unsigned8 MODE_BIT                                  = 0x02;
static const Unsigned8 SCAN_BIT                                  = 0x04;
static const Unsigned8 AP_BIT                                    = 0x08;
static const Unsigned8 LED_MASK                   = 0x0F;


static const Unsigned32 USEC_PER_SEC = 1000000L;
static const Unsigned32 FREE_RUN_CLK_HZ = 32768L;

static const SFD_LEN      = 2;      // For SFD A0 F3
static const SFD_B0      = 0xa0;     // 1st SFD byte for DS PHY
static const SFD_B1      = 0xf3;     // 2nd SFD byte for DS PHY

static const PREAMBLE_LEN    = 15;
//static const PREAMBLE_LEN    = 60;    // ***RJT***KME TEST***

static const PLCP_LEN  = 6;         //  Length of DS PLCP header

#define kcbSynthTableElement  5
typedef struct synth_data_struct {
    Unsigned8
      au8SynthElement [kcbSynthTableElement] ;
} Synth_Data_Type ;

   #define kcbH3824RegWriteTableElement  5
typedef struct h3824_data_struct {
    Unsigned8
      au8H3824WElement[kcbH3824RegWriteTableElement] ;
} H3824_Data_Type ;

extern const far Synth_Data_Type astSynthesizer_RFNTable[];

Unsigned8 initialize_3824(void);
void initialize_PLL(void);

class Preamble_Type        // *****RJT*****
{
  protected:
  public:
    Unsigned8  preamble[PREAMBLE_LEN];
    Unsigned16 SFD;

    Preamble_Type();
#ifdef COAX
    /*
     *  The set_SFD method is used to test channel 'tuning' when using a
     * coax test bed.  The call will change the two bytes of the preamble
     * which is used by the coax version in its SFD detection.
     */
    void set_SFD(Unsigned8 channel);
#endif  // COAX
};


/*  This class defines the fields used in the Frequency Hopper PHY PLCP
 *  header. Also provided are methods to allow changing of the header
 *  fields.
 */

class PLCP_Header_Type
{
  protected:
    Unsigned8  ds_signal;
    Unsigned8  ds_service;
    Unsigned16 ds_length;
    Unsigned16 ds_error_check;

  public:
    PLCP_Header_Type();

    void set_signal(Unsigned8 rate);
    void set_service(Unsigned8 rate);
    void set_length1Mb(Unsigned16 length);
    void set_length2Mb(Unsigned16 length);
    void set_EC();
    const Unsigned16 CRC_16();

    const Unsigned16 get_length() const;
    const Unsigned8  get_rate() const;
    const Unsigned16 get_EC() const;
}; /* end class PLCP_Header_Type */


#endif /* RADIOAPI_HPP */
