#ifndef SYNTH_TABLE_CPP
#define SYNTH_TABLE_CPP

/*
 *
 * Radio API source module for PCnet-MOBILE 802.11 protocol firmware.
 *
 * Copyright (c) 1996, 1997, 1998 Advanced Micro Devices, Inc.
 * All rights reserved.
 *
 * Version 2.0
 *
 * Controller & Switch Development (CSD)
 *
 * Module Name: synthszr.cpp
 *
 * Globals Accessed:
 *
 * Callers:
 *
 * Called routines:
 *
 * Functional Description:
 *
 * Comments:
 *
 * Diagnostics:
 *
 */

#include "types.hpp"
#include "radioapi.hpp"

/*
; Format of the arguments to the 'element generating' macro PLLNElmt
; (defined in DS_RADIO.HPP):
;
; PLLNElmt ( PGM(N19.N20), DivRatioB(N18..N8), DivRatioA(N7..N1), CTRL(C1.C2) )
;
; PGM bits, CTRL bits, and the DivRatios are derived from the
; Harris HFA3524 Dual Frequency Synthesizer datasheet.
;
*/


const far Synth_Data_Type astSynthesizer_RFNTable[kcSynthElements] = {
// The arguments to the macro PLLNElmt() are derived from the HFA3524 datasheet
// for a 22-bit Programmable Divide (N Counter) serial register
// Uses macro PLLNElmt()
//  PLLNElmt (PGM(N19.N20), DivRatioB(N18..N8), DivRatioA(N7..N1), CTRL(C1.C2))

// The dummy entry for channel # 0 produces 25 bits (debug, never used)
//  {{0xA1, 0xA2, 0xA4, 0xA8, 0xB0}} ,              // dummy channel # 0
  {{PLLNElmt(0, 66, 20, 3) }} ,               // chnl # 01 (2.412GHz) index 0
  {{PLLNElmt(0, 66, 20, 3) }} ,               // chnl # 01 (2.412GHz)
  {{PLLNElmt(0, 66, 25, 3) }} ,               // chnl # 02 (2.417GHz)
  {{PLLNElmt(0, 66, 30, 3) }} ,               // chnl # 03 (2.422GHz)
  {{PLLNElmt(0, 67,  3, 3) }} ,               // chnl # 04 (2.427GHz)
  {{PLLNElmt(0, 67,  8, 3) }} ,               // chnl # 05 (2.432GHz)
  {{PLLNElmt(0, 67, 13, 3) }} ,               // chnl # 06 (2.437GHz)
  {{PLLNElmt(0, 67, 18, 3) }} ,               // chnl # 07 (2.442GHz)
  {{PLLNElmt(0, 67, 23, 3) }} ,               // chnl # 08 (2.447GHz)
  {{PLLNElmt(0, 67, 28, 3) }} ,               // chnl # 09 (2.452GHz)
  {{PLLNElmt(0, 68,  1, 3) }} ,               // chnl # 10 (2.457GHz)
  {{PLLNElmt(0, 68,  6, 3) }} ,               // chnl # 11 (2.462GHz)
  {{PLLNElmt(0, 68, 11, 3) }} ,               // chnl # 12 (2.467GHz)
  {{PLLNElmt(0, 68, 16, 3) }} ,               // chnl # 13 (2.472GHz)
  {{PLLNElmt(0, 68, 28, 3) }}                 // chnl # 14 (2.484GHz)
}; /* end Synthesizer_RFNTable */


#endif /* SYNTH_TABLE_CPP  */

