#ifndef DRIVER_H
#define DRIVER_H

/*
 *
 * Radio API source module for PCnet-MOBILE 802.11 protocol firmware.
 *
 * Copyright (c) 1996, 1997, 1998 Advanced Micro Devices, Inc.
 * All rights reserved.
 *
 * Version 2.0
 *
 * Controller & Switch Development (CSD)
 *
 * Module Name: driver.h
 *
 * Globals Accessed:
 *
 * Callers:
 *
 * Called routines:
 *
 * Functional Description:
 * This file contains the host interface structure definitions as defined
 * in the AP Firmware Architecture Specification.
 *
 * Comments:
 *
 */

#include "types.hpp"

  static const CMD_BLK_PARM_SIZE              = 76 ;

  typedef struct command_block_struct {

    Unsigned8           Command ;
    Unsigned8           Status ;
    Unsigned8           Error_Offset ;
    Unsigned8           Reserved ;
    Unsigned8           Parameters[CMD_BLK_PARM_SIZE] ;

  } Command_Block_Type ;

  typedef struct control_block_struct {

    Unsigned8           Self_Test_Status ;
    Unsigned8           STA_State ;
    Unsigned8           Rsvd_For_User_Rtn ;
    Unsigned8           Interrupt_Status ;
    Unsigned8           Interrupt_Mask ;
    volatile Unsigned8  Lockout_PCnet_MOBILE ;
    volatile Unsigned8  Lockout_Host ;
    Unsigned8           Interrupt_Status2 ;
    Unsigned32          Reserved ;
    Unsigned8           SW_Dis_Pwr_Dn ;
    Unsigned8           Interrupt_Mask2 ;
    Unsigned8           Driver_State ;
    Unsigned8           Reserved2 ;

  } Control_Block_Type ;

  static const VIRTUAL_BIT_MAP_SIZE           = 251 ;

  typedef struct virtual_bit_map_struct {

    Unsigned8           Offset ;
    Unsigned8           Length ;
    Unsigned8           Bit_Map[VIRTUAL_BIT_MAP_SIZE] ;

  } Virtual_Bit_Map_Type ;

/*****************************************************************/
  static const NO_COMMAND                   = 0x00 ;

/*****************************************************************
 *  Command and related definitions
 *****************************************************************/
  static const TEST_INTERFACE_NOP           = 0x01 ;

/*****************************************************************/
  static const GET_MIB_VARIABLES            = 0x09 ;
  static const SET_MIB_VARIABLES            = 0x02 ;

  static const MIB_CMD_DATA_SIZE            = 72 ;

  typedef struct {

    Unsigned8           Type ;
    Unsigned8           Size ;
    Unsigned8           Index ;
    Unsigned8           reserved ;
    Unsigned8           Data[MIB_CMD_DATA_SIZE] ;

  } MIB_Variable_Cmd_Parm_Struct ;

// Allowed Type field values

  static const LOCAL_MIB_TYPE               = 0x00 ;
  static const BOARD_MIB_TYPE               = 0x01 ;
  static const MAC_ADDRESS_STATUS_MIB_TYPE  = 0x02 ;
  static const MAC_MIB_TYPE                 = 0x03 ;
  static const STATISTIC_MAC_MIB_TYPE       = 0x04 ;
  static const MAC_MGMT_MIB_TYPE            = 0x05 ;
  static const DRVR_MAC_MGMT_MIB_TYPE       = 0x06 ;
  static const PHY_MIB_TYPE                 = 0x07 ;

/*****************************************************************/
static const ENABLE_TRANSMITTER             = 0x03 ;

  typedef struct {

    union {
      char        init_data_desc_bytes[4] ;
      Offset_Type Init_Data_Desc ;
    } ; /* end union */

    union {
      char        init_mgmt_desc_bytes[4] ;
      Offset_Type Init_Mgmt_Desc ;
    } ; /* end union */

    union {
      char        init_bcast_desc_bytes[4] ;
      Offset_Type Init_Bcast_Desc ;
    } ; /* end union */

    union {
      char        init_ps_poll_desc_bytes[4] ;
      Offset_Type Init_PS_Poll_Desc ;
    } ; /* end union */

    union {
      char        init_CF_poll_desc_bytes[4] ;
      Offset_Type Init_CF_Poll_Desc ;
    } ; /* end union */

  } En_Tx_Cmd_Parm_Struct ;

/*****************************************************************/
  static const DISABLE_TRANSMITTER          = 0x04 ;

  typedef struct {

    Boolean             Data ;
    Boolean             Mgmt ;
    Boolean             Bcast ;
    Boolean             PS_Poll ;
    Boolean             CF_Poll ;

  } Dis_Tx_Cmd_Parm_Struct ;

/*****************************************************************/
  static const ENABLE_RECEIVER              = 0x05 ;

  typedef struct {

    union {
      char        init_data_desc_bytes[4] ;
      Offset_Type Init_Data_Desc ;
    } ; /* end union */

    union {
      char        init_mgmt_desc_bytes[4] ;
      Offset_Type Init_Mgmt_Desc ;
    } ; /* end union */

  } En_Rx_Cmd_Parm_Struct ;

/*****************************************************************/
  static const DISABLE_RECEIVER             = 0x06 ;

/*****************************************************************/
  static const SLEEP                        = 0x07 ;

  typedef struct {
    Unsigned64  Wake_Up_Time ;
  } Sleep_Cmd_Parm_Struct ;

/*****************************************************************/
  static const WAKE                         = 0x08 ;

/*****************************************************************/
  static const SCAN                         = 0x0a ;

  typedef struct {

    Unsigned16          Duration ;
    Unsigned8           Set_Channel ;
    Unsigned8           Pattern ;
    Unsigned8           Index ;
    Unsigned8           Suspend ;

  } Scan_Cmd_Parm_Struct ;

  // Allowed Mode field values
  static const ACTIVE                       = 0x01 ;
  static const HOP                          = 0x02 ;
  static const SYNCED                       = 0x04 ;

/*****************************************************************/
  static const SYNC                         = 0x0b ;

  typedef struct {

    Unsigned8           Set_Channel ;
    Unsigned8           Pattern ;
    Unsigned8           Index ;
    Boolean             Start_BSS ;
    Unsigned16          Dwell_Interval ;
    Unsigned16          reserved ;
    Unsigned64          BSS_Timestamp ;
    Unsigned32          Ref_Time ;

  } Sync_Cmd_Parm_Struct ;

/*****************************************************************/
  static const RESUME                       = 0x0c ;

/*****************************************************************/

/*****************************************************************
 *  Last Completed Descriptor Block definitions
 *
 *  These constants are the offsets where the firmware will write
 *  the offset of the last completed tx descriptor of the respective
 *  queue. These are actually in the top space of the vector table of
 *  the 80188.
 *****************************************************************/
  static const LAST_BCAST_OFFSET            = 0x3ec ;
  static const LAST_MGMT_OFFSET             = 0x3f0 ;
  static const LAST_DATA_OFFSET             = 0x3f4 ;
  static const LAST_PS_POLL_OFFSET          = 0x3f8 ;
  static const LAST_CF_POLL_OFFSET          = 0x3fc ;

/*****************************************************************
 *  Banner Block definition
 *****************************************************************/
  static const BANNER_SIZE                  = 32 ;


/*****************************************************************
 *  Generic Status definitions
 *****************************************************************/
  static const IDLE                         = 0x00 ;
  static const DONE_GOOD                    = 0x01 ;
  static const UNKNOWN_COMMAND              = 0x02 ;
  static const INVALID_PARAMETER            = 0x03 ;
  static const NOT_SUPPORTED                = 0x04 ;
  static const UNKNOWN_FAILURE              = 0x05 ;
  static const INVALID_COMMAND              = 0x06 ;

/*****************************************************************
 *  Self_Test_Status and related definitions
 *****************************************************************/

  static const DEAD                         = 0x00 ;
  static const START                        = 0x01 ;
  static const HARDWARE_TEST                = 0x02 ;
  static const MIB_INIT                     = 0x03 ;
  static const RADIO_INIT_FAIL              = 0xF9 ;
  static const MIB_FAIL                     = 0xFA ;
  static const RADIO_FAIL                   = 0xFB ;
  static const SUTRO_FAIL                   = 0xFC ;
  static const FLASH_FAIL                   = 0xFD ;
  static const RAM_FAIL                     = 0xFE ;
  static const SUCCESS                      = 0xFF ;

/*****************************************************************
 *  STA_State and related definitions
 *****************************************************************/

  static const TX_ENABLED                   = 0x01 ;
  static const RX_ENABLED                   = 0x02 ;
  static const PSP_MODE                     = 0x04 ;
  static const DOZE                         = 0x08 ;
  static const PSP_DIS                      = 0x10 ;
  static const AP_ACTIVE                    = 0x20 ;

/*****************************************************************
 *  Interrupt_Status, Interrupt_Mask and related definitions
 *****************************************************************/

  static const CMD_CMPLT                    = 0x01 ;
  static const RX_INT                       = 0x02 ;
  static const TX_INT                       = 0x04 ;
  static const SCAN_CMPLT                   = 0x08 ;
  static const CFP_STARTING                 = 0x10 ;
  static const DTIM_STARTING                = 0x20 ;
  static const CFP_ENDING                   = 0x40 ;
  static const WAKING_UP                    = 0x80 ;

/*****************************************************************
 *  Interrupt_Status2, Interrupt_Mask2 and related definitions
 *****************************************************************/

  static const TX_DATA                      = 0x01 ;
  static const TX_BCAST                     = 0x02 ;
  static const TX_PS_POLL                   = 0x04 ;
  static const TX_CF_POLL                   = 0x08 ;
  static const TX_MGMT                      = 0x10 ;
  static const RX_DATA                      = 0x40 ;
  static const RX_MGMT                      = 0x80 ;
  static const TX_QUEUES                    = 0x1f ;
  static const RX_QUEUES                    = 0xc0 ;

#endif /* DRIVER_H */

