#ifndef MIB_HPP
#define MIB_HPP

/*
 *
 * Radio API source module for PCnet-MOBILE 802.11 protocol firmware.
 *
 * Copyright (c) 1996, 1997, 1998 Advanced Micro Devices, Inc.
 * All rights reserved.
 *
 * Version 2.0
 *
 * Controller & Switch Development (CSD)
 *
 * Module Name: mib.hpp
 *
 * Globals Accessed:
 *
 * Callers:
 *
 * Called routines:
 *
 * Functional Description:
 * This file contains the MIB structure definitions as defined in the
 * AP Firmware Architecture Specification.
 *
 * Comments:
 *
 */


#include "types.hpp"

static const ESS_ID_SIZE          = 34 ;
static const NUM_GROUP_ADDRESSES  = 4 ;

typedef struct MAC_Mgmt_MIB_Struct {

  enum {
    ACTIVE_MODE = 0x00 ,
    PS_MODE = 0x10
  }             aPower_Mgt_Mode ;

  enum {
    PASSIVE_SCAN    = 0x00 ,
    ACTIVE_SCAN     = 0x01 ,
    BG_PASSIVE_SCAN = 0x02 ,
    BG_ACTIVE_SCAN  = 0x03 ,
    BG_SCAN_BIT     = 0x02 ,
    ACTIVE_BIT      = 0x01
  }             aScan_Mode ;

  Boolean       aScan_State ;
  Unsigned8     aDTIM_Period ;
  Unsigned16    aATIM_Window ;
  Boolean       WEP_Required ;
  Boolean       Reserved ;
  Unsigned16    aBeacon_Period ;
  Unsigned16    aPassive_Scan_Duration ;
  Unsigned16    aListen_Interval ;
  Unsigned16    aMedium_Occupancy_Limit ;
  Unsigned16    aMax_MPDU_Time ;
  Unsigned16    aCFP_Max_Duration ;
  Unsigned8     aCFP_Rate ;
  Boolean       Do_Not_Receive_DTIMs ;
  Unsigned16    aStation_ID ;
  Unsigned48    aCurrent_BSS_ID ;
  Unsigned8     aCurrent_ESS_ID[ESS_ID_SIZE] ;

} MAC_Mgmt_MIB_Type ;


typedef struct Statistic_MAC_MIB_Struct {

  Unsigned32    aTransmitted_MPDU_Count ;
  Unsigned32    aTransmitted_MSDU_Count ;
  Unsigned32    aOctets_Transmitted_Count ;
  Unsigned16    aMulticast_Transmitted_Frame_Count ;
  Unsigned16    aBroadcast_Transmitted_Frame_Count ;
  Unsigned32    aFailed_Count ;
  Unsigned32    aRetry_Count ;
  Unsigned32    aMultiple_Retry_Count ;
  Unsigned32    aFrame_Duplicate_Count ;
  Unsigned32    aRTS_Success_Count ;
  Unsigned32    aRTS_Failure_Count ;
  Unsigned32    aACK_Failure_Count ;
  Unsigned32    aReceived_Frame_Count ;
  Unsigned32    aOctets_Received_Count ;
  Unsigned16    aMulticast_Received_Count ;
  Unsigned16    aBroadcast_Received_Count ;
  Unsigned32    aFCS_Error_Count ;
  Unsigned32    aError_Count ;
  Unsigned32    aWEP_Undecryptable_Count ;

} Statistic_MAC_MIB_Type ;


typedef struct MAC_MIB_Struct {
  Unsigned16    Reserved1 ;
  Unsigned16    Reserved2 ;
  Unsigned16    aRTS_Threshold ;
  Unsigned16    aCW_max ;
  Unsigned16    aCW_min ;
  Unsigned8     aPromiscuous_Enable ;
  Unsigned8     Reserved3 ;
  Unsigned32    Reserved4 ;
  Unsigned8     aRTS_Retry_max ;
  Unsigned8     aData_Retry_max ;
  Unsigned16    aMax_Frame_Length ;
  Unsigned16    aFragmentation_Threshold ;
  Unsigned16    aProbe_Delay ;
  Unsigned16    aMin_Probe_Response_Time ;
  Unsigned16    aMax_Probe_Response_Time ;
    /* the MSDU lifetimes are in free count timer ticks */
  Unsigned32    aMax_Transmit_MSDU_Lifetime ;
  Unsigned32    aMax_Receive_MSDU_Lifetime ;
  Unsigned16    aStation_Basic_Rate ;
  Unsigned8     aDesired_ESS_ID[ESS_ID_SIZE] ;

} MAC_MIB_Type ;


typedef struct MAC_Address_Status_grp_Struct {
  Unsigned48    aMAC_Address ;
  Unsigned48    aGroup_Addresses[NUM_GROUP_ADDRESSES] ;
  Boolean       aTransmit_Enable_Status ;
  Boolean       Reserved ;

} MAC_Address_Status_MIB_Type ;


typedef struct Local_MIB_Struct {
  Boolean       Fragmentation_Dis ;
  Boolean       Add_PLCP_Dis ;
  Boolean       MAC_Hdr_Prsv ;
  Boolean       Rx_Mgmt_Que_En ;
  Boolean       Re_Assembly_Dis ;
  Boolean       Strip_PLCP_Dis ;
  Boolean       Rx_Error_Dis ;
  Boolean       Power_Saving_Mode_Dis ;
  Boolean       Accept_All_Multicast_Dis ;
  Boolean       Check_Seq_Cntl_Dis ;
  Unsigned8     Flush_CFP_Queue_On_CF_End ;
  Boolean       Network_Mode ;
  Unsigned8     PWD_Lvl ;
  Boolean       CFP_Mode ;
  Unsigned32    Tx_Buffer_Offset ;
  Unsigned32    Tx_Buffer_Size ;
  Unsigned32    Rx_Buffer_Offset ;
  Unsigned32    Rx_Buffer_Size ;
  Boolean       Acting_As_AP ;

  enum {
    FILL_OFF  = 0x00 ,
    FILL_ON   = 0x01 ,
    FILL_MAX  = 0x02
  }             Fill_CFP ;

} Local_MIB_Type ;


static const PWR_LVL_TABLE_SIZE = 4 ;

typedef struct PHY_MIB_struct {

  Unsigned16    aSlot_Time ;
  Unsigned16    aSIFS ;
  Unsigned16    aMPDU_Maximum ;
  Unsigned16    aHop_Time ;
  Unsigned8     aSuprt_Data_Rates[4] ;

  enum {
    FCC     = 0x10 ,
    IC      = 0x20 ,
    ETSI    = 0x30 ,
    FRANCE  = 0x32 ,
    SPAIN   = 0x31 ,
    MKK     = 0x40
  }             aCurrent_Reg_Domain ;

  Unsigned8     aPreamble_Lngth ;
  Unsigned8     aPLCP_Hdr_Lngth ;
  Unsigned16    Pwr_Up_Time[PWR_LVL_TABLE_SIZE] ;
  Unsigned8     IEEE_PHY_Type ;
  Unsigned8     RCR_33A_Bits [8] ;

} PHY_MIB_Type ;


#endif  /* MIB_HPP  */








