	page	60, 132
	name	attribut
	title	SUTRO Attribute memory definition

;
;
	INCLUDE	startup.inc		; Macros/assembly language definitions
;
; This segment contains the PCMCIA Attribute memory contents which is kept in a
; 1K section of FLASH that is mapped into the first 1K space of shared memory.
;

DefSeg	_PCMCIA_ATTR, para,  public,   PCMCIA_ATTR,  <>	  ; Attribute constants


_PCMCIA_ATTR	segment


;****************************************************************************
;* Note:  These comments describe the tuples and the fields of those tuples *
;* which are used to describe this card.  The comments may or may not be a  *
;* complete description of a particular tuple.                              *
;****************************************************************************
;
; CISTPL_CHECKSUM:  The Checksum Tuple
; For additional reliability, the CIS can contain one or more checksum tuples.
; This tuple has three fields:
; (1) the relative address of the block of CIS memory to be checked
; (2) The length of the block of CIS memory to be checked
; (3) The expected check sum
; The checksum algorithm is a straigh modulo-256 sum.  Relative address is used
; to make the CIS, as a whole, position independent.  The cheksum tuple can
; only validate memory in its own address space.
;
; byte
; 0     TPL_CODE    CISTPL_CHKECSUM (10h)
; 1     TPL_LINK    Link to next tuple (05h)
; 2-3   TPLCKS_ADDR Offset to region to be checksummed, stored LSB first
; 4-5   TPLCKS_LEN  Length of region to be checksummed, given with LSB first
; 6     TPLCKS_CS   The checksum of the region
;
;    db  010h, 005h, 007, 000h, 000h, 000h, 000h
;
;****************************************************************************

;****************************************************************************
; CISTPL_DEVICE:  The 5 Volt Device Information Tuple
; The 5 Volt device information tuple contains information about the card's
; devices.  The tuples contain: device speed, device size, device type and
; address space layout information for Common Memory space.  PC Cards with
; a 5 Volt key shall present a device information tuple for Common Memory
; space as the first non-control tuple in Attribute memory.
;
; byte
; 0     TPL_CODE    CISTPL_DEVICE (01h)
; 1     TPL_LINK    Link to next tuple (at least m-1)
; n                 Device Info 1 (2 or more bytes)
;                   Device Info 2 (2 or more bytes)
; ...
; m     0ffh        End of Device Info field
;
; Device Info fields
; The device information tuples are composed of a sequence of Device Info
; fields.  Each field is further composed of two variable length byte
; sequences - the Device ID and the Device Size.  Each Device Infor field
; defines the characteristeics of a group of address in the appropriate
; memory space.
;
; byte
; n     Device ID   one ore more bytes of Device ID fields
; n+m   Device Size one byte indicates the device size
;       bits
;       7-3     # of address units - 1
;       2-0     Size Code
;
; Device ID fields
; The device ID indicates the device type and the access time for a block of
; memory.
;
; byte  bits
; n     7-4     Device Type Code
;       3       WPS
;       2-0     Address Space Indicator or Device Speed
; device type code field = DTYPE_NULL No device.  If used for a 16-bit PC
; Card, the Device speed should be set to 0h.
; The WPS field indicates whether or not the Write Protect Switch is in
; control ov the device(s) in this address range.  When the WPS bit is 0, the
; Write Protect and WP signal indicate whether or not the devices(s) is(are)
; writable.  When the WPS bit is 1, the device is always writable unless the
; device code is DTYPE_ROM, in which case this address range is never
; writable.
;
; # of address units - 1    = 1 - 1 = 0
; Size Code                 = 3 (32 KBytes units)

;    db  001h, 003h, 000h, 003h, 0ffh
    db	001h, 003h, 0D9h, 003h, 0ffh

;****************************************************************************

;****************************************************************************
; CISTPL_DEVICE_OC:  The Other Conditions Device Information Tuple
; The Other Conditions device information tuple contains information about
; the card's devices under a set of operating conditions.  This tuple is
; identical in format to the CISTPL_DEVICE tuple except that an Other-
; Conditions-Info field preceeds the first Device Info field. There may be
; several CISTPL_DEVICE_OC tuples in the CIS- one to describe the card
; under each set of alternating operating conditions.
;
; Other than the Other Conditions Info field, there shall be a one-to-one
; correspondence between the entries of the CISTPL_DEVICE tuple and
; this CISTPL_DEVICE_OC tuple.
;
; byte
; 0     TPL_CODE    CISTPL_DEVICE_OC (01Ch)
; 1     TPL_LINK    Link to next tuple (at least m-1)
; 2		    Other Conditions Info (1 or more bytes)
; n                 Device Info 1 (2 or more bytes)
;                   Device Info 2 (2 or more bytes)
; ...
; m     0ffh        End of Device Info field
;
; Other Conditions Info field
; The Other Conditions Info field is a sequence of one or more bytes each
; with up to seven condirion fields and one extension bit. There are two
; conditions fields defined- the VccUsed and the MWAIT fields.
;
; Other Conditions Info: 001h 5.0V Vcc, MWAIT pin supported
;
; All other fields in this CISTPL_DEVICE_OC tuple are defined identically
; as in the CISTPL_DEVICE tuple section.

    db	01Ch, 004h, 001h, 0D9h, 003h, 0ffh

;****************************************************************************

;****************************************************************************
; CISTPL_DEVICE_A :  The 5 Volt Device Information Tuple
; The 5 Volt device information tuple contains information about the card's
; devices.  The tuples contain: device speed, device size, device type and
; address space layout information for Attribute Memory space.
;
; byte
; 0     TPL_CODE    CISTPL_DEVICE_A (17h)
; 1     TPL_LINK    Link to next tuple (at least m-1)
; n                 Device Info 1 (2 or more bytes)
;                   Device Info 2 (2 or more bytes)
; ...
; m     0ffh        End of Device Info field
;
; byte  bits
; n     7-4     Device Type Code
;       3       WPS
;       2-0     Address Space Indicator or Device Speed
; device type code  = DTYPE_FLASH, Flash EPROM.
; WPS               = the device is always writable
; device speed code = DSPEED_250NS (01h) 250ns
;
; # of address units - 1    = 1 - 1 = 0
; Size Code                 = 1 (2 KBytes units)

;    db  017h, 003h, 059h, 001h, 0ffh
    db  017h, 003h, 0D9h, 001h, 0ffh

;****************************************************************************
; CISTPL_DEVICE_OA:  The Other Conditions Device Information Tuple
; The Other Conditions device information tuple contains information about
; the card's devices under a set of operating conditions.  This tuple is
; identical in format to the CISTPL_DEVICE_A tuple except that an Other-
; Conditions-Info field preceeds the first Device Info field. There may be
; several CISTPL_DEVICE_OA tuples in the CIS- one to describe the card
; under each set of alternating operating conditions.
;
; Other than the Other Conditions Info field, there shall be a one-to-one
; correspondence between the entries of the CISTPL_DEVICE_A tuple and
; this CISTPL_DEVICE_OA tuple.
;
; byte
; 0     TPL_CODE    CISTPL_DEVICE_OA (01Dh)
; 1     TPL_LINK    Link to next tuple (at least m-1)
; 2		    Other Conditions Info (1 or more bytes)
; n                 Device Info 1 (2 or more bytes)
;                   Device Info 2 (2 or more bytes)
; ...
; m     0ffh        End of Device Info field
;
; Other Conditions Info field
; The Other Conditions Info field is a sequence of one or more bytes each
; with up to seven condirion fields and one extension bit. There are two
; conditions fields defined- the VccUsed and the MWAIT fields.
;
; Other Conditions Info: 001h 5.0V Vcc, MWAIT pin supported
;
; All other fields in this CISTPL_DEVICE_OA tuple are defined identically
; as in the CISTPL_DEVICE_A tuple section.

    db  01Dh, 004h, 001h, 0D9h, 001h, 0ffh

;****************************************************************************

;****************************************************************************
; CISTPL_MANFID:  Manufacturer Identification Tuple
; The manufacturer identification tuple contains information about the
; manufacturer of a PC Card.  Two types of information are provided:  the PC
; Card's manufacturer and a manufacturer card number.  Only on manufacturer
; identification tuple may be present in the card information structure.
;
; byte
; 0     TPL_CODE    CISTPL_MANFID (20h)
; 1     TPL_LINK    Link to next tuple (at least 04h)
; 2-3   TPLMID_MANF PC Card manufacturer code
; 4-5   TPLMID_CARD manufacturer information (part number and/or revision)
;
; The TPLMID_CARD field is reserved for use by the PC Card's manufacturer.
; It is anticipated that the field will be used to store card identifier and
; revision information.

    db  020h, 004h, 000h, 000h, 000h, 000h

;****************************************************************************

;****************************************************************************
; CISTPL_FUNCID:  Function Identification Tuple
; The function identification tuple contains information about the
; functionality provided by a PC Card.  Information is also provided to
; enable system utilities to decide if the PC Card should be configured
; during system initialization.  If additional function specific information
; is available, one or more function extension tuples follow this tuple.
;
; byte
; 0     TPL_CODE        CISTPL_FUNCID (21h)
; 1     TPL_LINK        Link to next tuple (at least 2)
; 2     TPLFID_FUNCTION IC Card function code
; 3     TPLFID_SYSINIT  system initialization bit mask
;       bits
;       7-2     Reserved for future use
;       1       ROM
;       0       POST
; The ROM bit indicates the PC Card contains a system expansion ROM which may
; be installed during system initialization.
; The POST bit indicates that the Power-On Self Test routines may attempt to
; configure the PC Card during system intialization.
;
; TPLFID_FUNCTION       = 6 (Network adapter)
; TPLFID_SYSINIT        = ROM = 0; POST = 0

    db  021h, 002h, 006h, 000h

;****************************************************************************

;****************************************************************************
; CISTPL_FUNCE:  Function Extension Tuple
; The function extension tuple contains information about a specific PC Card
; function.  The information proviced is determined by the function
; identification tuple, CISTPL_FUNCID, that is being extended.  Each function
; has a defined set of extension tuples.
;
; byte
; 0     TPL_CODE        CISTPL_FUNCE (22h)
; 1     TPL_LINK        Link to next tuple
; 2     TPLFE_TYPE      Type of extended data
; 3     TPLFE_DATA      function information
;
; TPLFE_TYPE
; 1 - LAN_TECH  Technology type
; 2 - LAN_SPEED Raw bit rate
; 3 - LAN_MEDIA cable or transmission media
; 4 - LAN_NID   node identification
; 5 - LAN_CONN  connector standard

; LAN_TECH
; LAN_TECH_CODE network technology code = 7 (wireless)

    db  022h, 002h, 001h, 007h

; LAN_SPEED
; LAN_SPEED_VALUE is a 32-bit integer containing the raw network bit rate.
; Note: lsb is the first byte of data
; 1e8480h = 2,000,000 bps

    db  022h, 005h, 002h, 080h, 084h, 01eh, 000h

; LAN_MEDIA
; LAN_MEDIA_CODE
; cable or transmission media = 7 (spread spectrum radio 2.4GHz)

    db  022h, 002h, 003h, 007h

; LAN_NID
; LAN_NID_SZ number of bytes in LAN node ID = 6
; LAN_NID_CODE binary value of LAN node ID = undefined

    db  022h, 008h, 004h, 006h, 000h, 000h, 000h, 000h, 000h, 000h

; LAN_CONN
; LAN_CONN_CODE connector standard compliance code = 0 open connector std

    db  022h, 002h, 005h, 000h

;****************************************************************************

;****************************************************************************
; CISTPL_VERS_1:  The level 1 Version/Product Information tuple
; This tuple contains Level 1 version compliance and card manufacturer
; information.  It applies to Level 1 tuples only.  It should appear only
; once in each partition descriptor chain.
;
; byte
; 0     TPL_CODE        CISTPL_VERS_1 (15h)
; 1     TPL_LINK        Link to next tuple
; 2     TPLLV1_MAJOR    Major version number
; 3     TPLLV1_MINOR    Minor version number
; 4     TPLLV1_INFO     Production information
;                       name of manufacturer null terminated
;                       name of product null terminated
;                       additional product info (lot number) null terminated
;                       additional product info (pgrming cond) null terminated
; m     0ffh            marks the end of the chain

    db  015h, 012h, 005h, 000h
    db  'AMD', 000h
    db  'Am79C930', 000h
    db  000h                            ; no additional product info but just
    db  000h                            ; ..in case
    db  0ffh

;    db  015h, 01Dh, 005h, 000h
;    db  'AMD', 000h
;    db  'Am79C930', 000h
;    db  'Am79C930 - 802.11 MAC', 000h
;    db  0ffh

;****************************************************************************

;****************************************************************************
; CISTPL_CONFIG:  16-bit PC Card Configuration Tuple
; The Configuration tuple is used to describe the general characteristics of
; 16-bit PC Cards which can be configured for operation.  This includes cards
; containing I/O devices or using custom interfaces.  It may also describe
; PC Cards, including Memory Only cards, which exceed nominal power supply
; specifications, or which need descriptions of their power requirements or
; other information.
; The default interface, in the absence of a Configuration tuple, is a Memory
; Only interface.
; There may be no more than one Configuration tuple in the CIS.
; There are two types of 16-bit PC Card defined interfaces:
; (1) Those supporting Memory Card Only interface
; (2) Those supporting both the Memory and I/O interfaces
;
; byte
; 0     TPL_CODE        CISTPL_CONFIG (1ah)
; 1     TPL_LINK        Link to next tuple
; 2     TPCC_SZ         size of fields byte
;       bits
;       7-6             TPCC_RFSZ (reserved)
;       5-2             TPCC_RMSZ (size of TPCC_RMSK field)
;       1-0             TPCC_RASZ (size of TPCC_RADR)
;
; TPCC_RFSZ is the size of area presently reserved for future use 0, 1, 2 or
; 3 bytes.  Must be 0 at present.
;
; TPCC_RMSZ is the number of bytes in the Configuration Register presence
; mask field (TPCC_RMSK) field of the tuple plus 1.
;
; TPCC_RASZ is the number of bytes in the Configuration Registers Base
; Address in Attribute Memory.  Space field (TPCC_RADR) of this tuple is the
; value of this field plus 1.
;
; 3     TPCC_LAST       index # of last entry in the Card Configuration Table
;       bits
;       7-6             reserved
;       5-0             last index
; 4     TPCC_RADR       Configuration Registers Base Address in Attribute
;                       Memory Space.  1, 2, 3, or 4 bytes depending on the
;                       value in TPCC_RASZ field in TPCC_SZ.
; ?     TPCC_RMSK       Configuration Registers Present Mask. 1 to 16 bytes
;                       as in indicated by the TPCC_RMSZ field in TPCC_SZ.
; ?     TPCC_RSVD       reserved area 0..3 bytes. Must be zeros until defined
; ?     TPCC_SBTPL      The rest of the tuple is reserved for subtuple
;                       containing standardized optional additional
;                       information related to the Card Configuration.

    db  01ah, 005h, 001h, 002h, 000h, 008h, 003h
;    db  01ah, 005h, 001h, 004h, 000h, 008h, 003h

;****************************************************************************

;****************************************************************************
; CISTPL_CFTABLE_ENTRY:  16-bit PC Card Configuration Table Entry Tuple
; The initial portion of each entry of the 16-bit PC Card Configuration Table
; is given in a compact, standard form.  Additional information may be added
; to the compact information by appending tuple-formatted information within
; the interface definition or configuration entry tuples containing the
; Configuration Table Entry.  Subtuple codes 90h-bfh are reseved for vendor
; specific configuration information.
;
; The 16-bit PC Card Configuration Table organization for a Memory Only Card
; and an I/O Card are the same.  However, a Memory Only Card should not
; include I/O specific fields or tuples.  Fields related to Vcc, Vpp[2::1]
; and timing apply to all 16-bit PC Cards.
;
; 16-bit PC Card Configuration Table Entry tuples are used to specify each
; possible configuration of a card and to distinguish amoung the permitted
; configurations.  The Configuration tuple must preceed all Configuration
; Tuple Entry tuples.  The Configuration Table Entry, whose Configuration
; Table Index matches the last index in the Configuration tuple, must appear
; after all other Configuration Table Entries.
;
; When the default bit is set in the Configuration Table index byte, that
; configuration Table Entry provides the default values for entries which
; follow in the Card Configuration Table.
;
; When the default bit is not set in an entry's Configuration Table index
; byte, the entry provides default values which apply only to the
; configuration indicated by that entry's Configuration Table index
; (TPCE_INDX) byte.
;
; Values which are not present in a specific entry artaken from the card's
; most recently scanned default entry, as indicated in the specific fields
; below.
;
; byte
; 0     TPL_CODE        CISTPL_CFTABLE_ENTRY (1bh)
; 1     TPL_LINK        Link to next tuple
; 2     TPCE_INDX       Configuration Table Index Byte
; ..    TPCE_IF         Interface description field if TPCE_INDX Intface = 1
; ..    TPCE_FS         Feature selection byte
; ..    TPCE_PD         Power Description Structure
; ..    TPCE_TD         Configuration Timing Information field
; ..    TPCE_IO         I/O Space description field
; ..    TPCE_IR         Interrupt Request Description Structure
; ..    TPCE_MS         Memory Space Description Structure
; ..    TPCE_MI         Miscellaneous Features field
; ..    TPCE_ST         Additional information about the configuration
;                       in subtuple format
;
; TPCE_INDX:  The Configuration Table Index Byte
; The Configuration Table index byte contains the value to be written to the
; Card Configuration Option Register in order to enable the configuration
; described in the tuple.  In addition, this byte contains a bit to indicate
; that the configuration defined in this tuple should be taken as the default
; conditions for Configuration-Entry tuples that follow.
; bits
; 7 - Intface - a configuration byte follows this byte
; 6 - Default - The default conditions for following table entries are
; exactly those conditions specified in this entry.
; 5-0 - Configuration Entry Number
;
; TPCE_IF:  Interface Description Field
; The Interface Description field indicates the particular card interface
; which the configuration uses.  The interface type (Memory Only or Memory
; and I/O) is specified.  In addition, the card's requirements for system
; support of Battery Voltage Detect, Write Protect, READY and Wait functions
; may be indicated.
; bits
; 7 - M Wait Required
; WAIT# signal support required for memory cycles
; 6 - READY Active
; READY status active and should be recovered from the Pin Replacement
; register if not available on Pin 16
; 5 - WP Active
; Write Protect status is active and should be recovered from the Pin
; Replacement register is not available on Pin 33
; 4 - BVDs Active
; BVD1 and BVD2 signals are active and should be recovered from the Pin
; Replacement register is not available on Pins 62 and 63
; 3..0 - Interface Type = 01h I/O and Memory
;
; TPCE_FS:  Feature Selection Byte
; The feature selection byte indicates which compact descriptive fields are
; present within the table entry.  Those fields which are present are
; indicated by a 1 in the corresponding bit of the selector byte.  Within the
; entry, the fields are ordered in the order of the selector bits starting
; from bit 0 (lsb) to bit 7 (msb).
; bits
; 7 - MISC (1) a miscellaneous fields structure is present following the
; memory space description structure
; 6..5 - Mem Space (11b) A memory space descriptor byte followed by one or
; more window descriptors is present
; 4 - IRQ - (1) An Interrupt request description structure is present
; following the I/O space description structure.
; 3 - IO Space (1) An I/O space description structure is present following
; the timing description structure
; 2 - Timing (1) A timing description structure is present following the
; power description structure
; 1..0 - Power (01b) Vcc power description structure only
;
; Parameter Selection byte
; bit
; 6 - Pdwn I
; 5 - Peak I
; 4 - Avg I
; 0 - Nom V
; Parameter Definition in Power Description Structure
; bits
; 6..3 - Mantissa
; 2..0 - Exponent
;
; Nom V  - (1010 101b) mantissa (A) = 5   exponent (5) = 1 V
; Avg I  - (0101 110b) mantissa (5) = 2.5 exponent (6) = 100 mA
; Peak I - (0101 110b) mantissa (5) = 2.5 exponent (6) = 100 mA
; Pdwn I - (0101 101b) mantissa (5) = 2.5 exponent (5) = 10  mA
;
; TPCE_TD:  Configuration Timing Information
; bits
; 7..5 Reserved Scale 7 - This field is the power of 10 scale factor which is
; to be applied to a reserved time definition.  A value of 7 indicates that
; no initial or extended reserved speed bytes follow the READY extended
; speed bytes. (111b)
; 4..2 READY Scale - This field is the power of 10 scale factor to be applied
; to the MAX time in the Busy State for the READY signal.  A value of 7
; indicates that READY is not used and no maximum time is present following
; the timing scale factor byte. (111b)
; 1..0 WAIT Scale - The is the power of 10 scale factor to be applied to the
; MAX WAIT time in extended device speed format which follows.  The value
; 3 indicates that the WAIT# signal is not used and the MAX WAIT Speed is not
; present following the timing byte. (00b)
;
; extended device speed format for MAX WAIT
; bits
; 6-3 mantissa
; 2-0 exponent
; MAX WAIT - (0010 100b) mantissa (2) = 1.2 exponent (4) = 10 micro seconds
;
; TPCE_IO:  I/O Space Addresses Required For This Configuration
; The I/O Space descriptor indicates that the card requires a portion of its
; I/O address space be accessible withing the host's I/O address space.  The
; I/O Space entry consits of, at minimum, the I/O Space Definition byte.  If
; this bytes has the Range bit set, a Range descriptor byte follows the
; defintion byte, which is then followed by a series of Range Description
; fields.  Each Range description consists of either a Starting Address
; field, a length field, or both.  Mulitple range descriptions can be defined
; if the card has multiple I/O windows.
;
; bits
; 7 - Range (0) The I/O Space Definition byte is the only byte needed for
; this definition.  The card will respond to all enabled I/O accesses and
; uses IOAddrLines of address to distinguish amoung its I/O ports.  The host
; can select and 2 to the n boundary (N=IOAddrLines) for the card and
; generate enables for acdcesses at this host base address, with the amount
; of space  also equal to 2 to the n.
; 6..5 - Bus 16/8 (01b) card supports 8-bit I/O only
; 4..0 - IO Address Lines (00100b) The card must indicate in IOAddrLines
; the highest address line (plus 1) which it decodes to determine
; when it has been selected.  The card will determine which I/O addresses
; are actually selected within the I/O space that it decodes.  (4 address
; lines are decoded)
;
; TPCE_IR:  Interrupt Request Description Structure
; When the IRQ bit is set, it indicates that an interrupt description follows
; the I/O address bytes, if any.  The interrupt request levels specified by
; the Configuration Tuple Entry Tuple describe the preferred routing for the
; card's IREQ# line.  Routing of the IREQ# interrupt is performed by the host
; system which actually determines the system interrupt level used.  A client
; which is the sole consumer of the card's IREQ# interrupt may elect to
; route the IREQ# line to a level not specified by the Configuration Table
; Entry Tuple.  A generic card configuration utility which is not the
; ultimate consumer of the card's IRQ# interrupt should only route to the
; specified interrupt levels.  There are either one or three interrupt
; descriptions bytes as shown below.
;
; byte 0
; bit 4 - MASK
; byte 1
; IRQ 7 IRQ5 IRQ4 IRQ3
; byte 2
; IRQ15 IRQ14 IRQ13 IRQ12 IRQ11 IRQ10 IRQ9 IRQ8
;
; TPCE_MS:  Memory Space Description Structure
; The Memory Space description indicates the card requires a
; configuration-entry related portion of its Common Memory space be mapped
; into the host's address space.  This memory may be either direct mapped
; (no address translation is performed by the host), or may require that the
; host translated the host address to the corresponding card address in order
; to support the card.  In either case, for the host to support the card
; under this configuration, the host must access the card when the
; corresponding addresses are accessed by software.
;
; bit
; 7 Host Addr (0).  No host address field is present and the hsot address is
; arbitrary.
; 6..5 Card address size (01b).  The size of the card address fields in bytes
; The card address is in 256-byte pages.
; 4..3 Length size (01b).  The size of the length fields in bytes.  The
; length is in 256-byte pages.
; 2..0 Number of Windows (0). The number of window descriptors following
; minus 1.
;
; Length (80h) The length of the window in units of 256 bytes. 100h*80h=8000h
; 32 KBytes
;
; Card Address (00h).  The address to be accessed on the card corresponding
; to the host address.
;
; TPCE_MI:  Miscellanedous Features Field
; bit 5 - Pwr Down

; Note:  The difference between the configurations is that in the Feature
; Selection Byte no memory memory address space requirement is specified and
; the most recently scanned Configuration-Entry tuple with its defualt bit
; set should be used.
;
; Configuration #1: 16 bytes I/O, 32K Common Memory
;
    db  01bh, 012h
    db  0c1h				; Default, Interface byte, entry#
    db  081h				; MWAIT, I/O-Memory
    db  0fdh				; Vccdescr,timing_descr,io_descr
					; irq_descr,mem+descr,miscdescr
    db  071h, 055h, 02eh, 02eh, 02dh	; Pdwn,Peak,Avg current; Nom voltage
					; 5V, 250mA Avg, 250mA Peak, 25mA Pdwn
    db  0fch, 014h			; No reserved;no READY;WAIT scale = 0
					; 12 microsecond max WAIT time
    db  024h				; 8-bit I/O; 16 bytes of I/O
    db  010h, 0b8h, 0ffh		; IRQs 3,4,5,7,8,9,10,11,12,13,14,15
    db  028h, 080h, 000h		; 1 memory window, 1 length byte
					; 1 card addr byte, no host mem addr
					; 32K memory window, PCMCIA addr 0
    db  020h				; Misc byte: Supports Pwrdn

; Configuration #2: 16 bytes I/O, no Common Memory
;
    db  01bh, 00fh
    db  0c2h				; Default, Interface byte, entry#
    db  001h				; No MWAIT, I/O-Memory
    db  09dh				; Vccdescr,timing_descr,io_descr
					; irq_descr,no memory,miscdescr
    db  071h, 055h, 02eh, 02eh, 02dh	; Pdwn,Peak,Avg current; Nom voltage
					; 5V, 250mA Avg, 250mA Peak, 25mA Pdwn
    db  0fch, 014h			; No reserved;no READY;WAIT scale = 0
					; 12 microsecond max WAIT time
    db  024h				; 8-bit I/O; 16 bytes of I/O
    db  010h, 0b8h, 0ffh		; IRQs 3,4,5,7,8,9,10,11,12,13,14,15
    db  020h				; Misc byte: Supports Pwrdn

; Configuration #3: 40 (64) bytes I/O, 32K Common Memory
;
;    db  01bh, 012h
;    db  0c3h                ; Default, Interface byte, entry#
;    db  081h                ; MWAIT, I/O-Memory
;    db  0fdh                ; Vccdescr,timing_descr,io_descr
;                    ; irq_descr,mem+descr,miscdescr
;    db  071h, 055h, 02eh, 02eh, 02dh    ; Pdwn,Peak,Avg current; Nom voltage
;                    ; 5V, 250mA Avg, 250mA Peak, 25mA Pdwn
;    db  0fch, 014h          ; No reserved;no READY;WAIT scale = 0
;                    ; 12 microsecond max WAIT time
;    db  026h                ; 8-bit I/O; 64 allocated bytes of I/O
;    db  010h, 0b8h, 0ffh        ; IRQs 3,4,5,7,8,9,10,11,12,13,14,15
;    db  028h, 080h, 000h        ; 1 memory window, 1 length byte
;                    ; 1 card addr byte, no host mem addr
;                    ; 32K memory window, PCMCIA addr 0
;    db  020h                ; Misc byte: Supports Pwrdn
;
; Configuration #4: 40 (64) bytes I/O, no Common Memory
;
;    db  01bh, 00fh
;    db  0c4h                ; Default, Interface byte, entry#
;    db  001h                ; No MWAIT, I/O-Memory
;    db  09dh                ; Vccdescr,timing_descr,io_descr
;                    ; irq_descr,no memory,miscdescr
;    db  071h, 055h, 02eh, 02eh, 02dh    ; Pdwn,Peak,Avg current; Nom voltage
;                    ; 5V, 250mA Avg, 250mA Peak, 25mA Pdwn
;    db  0fch, 014h          ; No reserved;no READY;WAIT scale = 0
;                    ; 12 microsecond max WAIT time
;    db  026h                ; 8-bit I/O; 64 allocated bytes of I/O
;    db  010h, 0b8h, 0ffh        ; IRQs 3,4,5,7,8,9,10,11,12,13,14,15
;    db  020h                ; Misc byte: Supports Pwrdn

;****************************************************************************
; CISTPL_END

    db  0ffh

_PCMCIA_ATTR	ends



END

