#ifndef RADIO_HPP
#define RADIO_HPP

/*
/*
 *
 * Radio API source module for PCnet-MOBILE 802.11 protocol firmware.
 *
 * Copyright (c) 1996, 1997, 1998 Advanced Micro Devices, Inc.
 * All rights reserved.
 *
 * Version 2.0
 *
 * Controller & Switch Development (CSD)
 *
 * Module Name: radio.cpp
 *
 * Globals Accessed:
 *
 * Callers:
 *
 * Called routines:
 *
 * Functional Description:
 *
 * Comments:
 * This file contains the radio API prototypes as defined in the AP Firmware
 * Architecture Specification.
 *
 * Diagnostics:
 *
 */

#include "types.hpp"
#include "driver.h"


extern const Unsigned8 Crc_Table_LSB[256] ;
extern const Unsigned8 Crc_Table_MSB[256] ;


static const Unsigned8 INFRA_RED = 3 ;
static const Unsigned8 DIRECT_SEQUENCE = 2 ;
static const Unsigned8 FREQUENCY_HOPPING = 1 ;
static const Unsigned8 ONE_MBIT = 10 ;
static const Unsigned8 TWO_MBIT = 20 ;
static const Unsigned8 MAX_PLCP_HEADER_SIZE = 12 ;

static const RX_DMA_TIMEOUT_VALUE = 128 ;
static const GOOD_CRC = 0 ;
static const BAD_CRC = 1 ;
static const RX_DMA_TIMEOUT = 2 ;


extern volatile Control_Block_Type Control_Block ;


class Radio_API_Module
{
  protected:
    Unsigned8 saved_RSSI_value ;
  public:
    Radio_API_Module() {}

  const Boolean initialize(int reg_domain, char far* reg_domain_bytes) ;

  void preset_channel(const Unsigned8 channel) ;
  void change_channel(const Unsigned8 channel) ;
  void force_channel(const Unsigned8 channel) ;
  void wake() ;
  void sleep(const Unsigned8 level) ;
  void arm_tx() ;
  void enable_tx() ;
  const Unsigned8 enable_tx_if_good(const Unsigned16 good_length) const ;
  const Unsigned8 enable_response_if_good(const Unsigned16 good_length) const ;
  void stop_tx() ;
  void disable_tx() ;
  void reset_CCA() ;
  void enable_rx() ;

/*
 *  PHY type / Preamble / PLCP header related routines.
 */
  const Unsigned8 get_PHY_type() const ;
  const Unsigned8 get_hdw_delay() const ;
  const Unsigned8 get_tx_preamble_len() const ;
  const Unsigned8 get_rx_PLCP_header_len() const ;
  const Unsigned8 get_tx_PLCP_header_len() const ;
  const Boolean is_PLCP_header_good(const Unsigned8* PLCP_ptr) const ;
  const Unsigned32 get_PLCP_info(const Unsigned8* PLCP_ptr) ;
  const Unsigned16 get_length(const Unsigned8* PLCP_ptr) const ;
  void  build_PLCP_header(const Unsigned8* PLCP_start,
  const Unsigned16 length, const Unsigned8 rate) ;
  Unsigned8* get_tx_preamble() const ;
  void set_PHY_rate(const Unsigned8 rate) ;
  const Unsigned8  get_RSSI() const ;
  void save_RSSI() ;
  void user_function() ;

/*
 *  PHY related conversion routines.
 */
  const Unsigned16 rel_time_to_usec_est(const Unsigned16 clk_ticks) ;
  const Unsigned32 rel_time_to_usec(const Unsigned24& rel_time) ;
  const Unsigned32 usec_to_rel_time(const Unsigned32& usec_time) ;
/*
 *  CPU clock and wait state init routines.
 */
  void pgm_clkgt20() const ;
  void set_wait_states() const ;

} ; /* end class Radio_API_Module */

#endif /* RADIO_HPP */
