#ifndef REGISTERS_HPP
#define REGISTERS_HPP

/*
/*
 *
 * Radio API source module for PCnet-MOBILE 802.11 protocol firmware.
 *
 * Copyright (c) 1996, 1997, 1998 Advanced Micro Devices, Inc.
 * All rights reserved.
 *
 * Version 2.0
 *
 * Controller & Switch Development (CSD)
 *
 * Module Name: register.hpp
 *
 * Globals Accessed:
 *
 * Callers:
 *
 * Called routines:
 *
 * Functional Description:
 *
 * Comments:
 * Am79C930 Register definitions.
 *
 */

#include "types.hpp"

extern volatile  Unsigned8 TIR[32] ;
extern volatile  Unsigned8 MIR[32] ;
extern volatile  Unsigned8 Reserved_1[64] ;

/*  Define the Vector Type names for use in EOI register call */

  static const unsigned char DIVIDE_ERROR_EXCPTN    = 0 ;
  static const unsigned char SINGLE_STEP_INT        = 1 ;
  static const unsigned char NON_MASKABLE_INT       = 2 ;
  static const unsigned char BREAKPOINT_INT         = 3 ;
  static const unsigned char INTO_DTCTD_OVFL_EXCPTN = 4 ;
  static const unsigned char ARRAY_BOUNDS_EXCPTN    = 5 ;
  static const unsigned char UNUSED_OPCODE_EXCPTN   = 6 ;
  static const unsigned char ESC_OPCODE_EXCPTN      = 7 ;
  static const unsigned char TIMER_0_INT            = 8 ;
  static const unsigned char TIMER_1_INT            = 18 ;
  static const unsigned char TIMER_2_INT            = 19 ;
  static const unsigned char DMA_0_INT              = 10 ;
  static const unsigned char DMA_1_INT              = 11 ;
  static const unsigned char INT0_INT               = 12 ;
  static const unsigned char INT1_INT               = 13 ;
  static const unsigned char INT2_INT               = 14 ;
  static const unsigned char INT3_INT               = 15 ;


/*  I/O mapped 80188 Control Registers  */

  static const Unsigned16 BASE                      = 0xFF00 ;


/*  Define Interrupt Controller Registers and bits  */

  static const Unsigned16 INT_CNTLR                 = BASE + 0x20 ;

  static const Unsigned16 EOI_REG                   = INT_CNTLR + 0x02 ;

  static const Unsigned16 N_SPECIFIC                = 0x8000 ;
  static const Unsigned16 SPECIFIC                  = 0x0000 ;

  static const Unsigned16 POLL_REG                  = INT_CNTLR + 0x04 ;
  static const Unsigned16 POLL_STATUS               = INT_CNTLR + 0x06 ;

  static const Unsigned16 INT_REQ                   = 0x8000 ;
  static const Unsigned16 S4                        = 0x0010 ;
  static const Unsigned16 S3                        = 0x0008 ;
  static const Unsigned16 S2                        = 0x0004 ;
  static const Unsigned16 S1                        = 0x0002 ;
  static const Unsigned16 S0                        = 0x0001 ;

  static const Unsigned16 PRIORITY_MASK             = INT_CNTLR + 0x0A ;

  static const Unsigned16 PRM2                      = 0x0004 ;
  static const Unsigned16 PRM1                      = 0x0002 ;
  static const Unsigned16 PRM0                      = 0x0001 ;
  static const Unsigned16 TAI_PRIORITY              = 0x0004 ;

  static const Unsigned16 MASK_REG                  = INT_CNTLR + 0x08 ;
  static const Unsigned16 IN_SERVICE                = INT_CNTLR + 0x0C ;
  static const Unsigned16 INTERRUPT_REQ             = INT_CNTLR + 0x0E ;

  static const Unsigned16 I3                        = 0x0080 ;
  static const Unsigned16 I2                        = 0x0040 ;
  static const Unsigned16 I1                        = 0x0020 ;
  static const Unsigned16 I0                        = 0x0010 ;
  static const Unsigned16 D1                        = 0x0008 ;
  static const Unsigned16 D0                        = 0x0004 ;
  static const Unsigned16 TMR                       = 0x0001 ;

  static const Unsigned16 INTERRUPT_STATUS          = INT_CNTLR + 0x10 ;

  static const Unsigned16 DHLT                      = 0x8000 ;
  static const Unsigned16 IRT2                      = 0x0004 ;
  static const Unsigned16 IRT1                      = 0x0002 ;
  static const Unsigned16 IRT0                      = 0x0001 ;

  static const Unsigned16 TIMER_INT_CONTROL         = INT_CNTLR + 0x12 ;
  static const Unsigned16 DMA_0_INT_CONTROL         = INT_CNTLR + 0x14 ;
  static const Unsigned16 DMA_1_INT_CONTROL         = INT_CNTLR + 0x16 ;
  static const Unsigned16 INT0_INT_CONTROL          = INT_CNTLR + 0x18 ;
  static const Unsigned16 INT1_INT_CONTROL          = INT_CNTLR + 0x1A ;
  static const Unsigned16 INT2_INT_CONTROL          = INT_CNTLR + 0x1C ;
  static const Unsigned16 INT3_INT_CONTROL          = INT_CNTLR + 0x1E ;

  static const Unsigned16 SFNM                      = 0x0040 ;
  static const Unsigned16 C                         = 0x0020 ;
  static const Unsigned16 LTM                       = 0x0010 ;
  static const Unsigned16 MSK                       = 0x0008 ;
  static const Unsigned16 PR2                       = 0x0004 ;
  static const Unsigned16 PR1                       = 0x0002 ; // PR0-2 set priority level of int
  static const Unsigned16 PR0                       = 0x0001 ;



/*  Define Timer 0,1 and 2 Registers and bits */


  static const Unsigned16 TIMER_0                   = BASE + 0x50 ;

  static const Unsigned16 TIMER_0_COUNT             = TIMER_0 + 0x00 ;
  static const Unsigned16 TIMER_0_MAX_A             = TIMER_0 + 0x02 ;
  static const Unsigned16 TIMER_0_MAX_B             = TIMER_0 + 0x04 ;
  static const Unsigned16 TIMER_0_MODE_CNTL         = TIMER_0 + 0x06 ;

  static const Unsigned16 TIMER_1                   = BASE + 0x58 ;

  static const Unsigned16 TIMER_1_COUNT             = TIMER_1 + 0x00 ;
  static const Unsigned16 TIMER_1_MAX_A             = TIMER_1 + 0x02 ;
  static const Unsigned16 TIMER_1_MAX_B             = TIMER_1 + 0x04 ;
  static const Unsigned16 TIMER_1_MODE_CNTL         = TIMER_1 + 0x06 ;

  static const Unsigned16 TIMER_2                   = BASE + 0x60 ;

  static const Unsigned16 TIMER_2_COUNT             = TIMER_2 + 0x00 ;
  static const Unsigned16 TIMER_2_MAX_A             = TIMER_2 + 0x02 ;
  static const Unsigned16 TIMER_2_MAX_B             = TIMER_2 + 0x04 ;
  static const Unsigned16 TIMER_2_MODE_CNTL         = TIMER_2 + 0x06 ;

  static const Unsigned16 EN                        = 0x8000 ;
  static const Unsigned16 DIS                       = 0x0000 ;
  static const Unsigned16 NO_INH                    = 0x4000 ;
  static const Unsigned16 INH                       = 0x0000 ;
  static const Unsigned16 TIMER_INT                 = 0x2000 ;
  static const Unsigned16 NO_INT                    = 0x0000 ;
  static const Unsigned16 B_RIU                     = 0x1000 ;
  static const Unsigned16 MC                        = 0x0020 ;
  static const Unsigned16 RTG                       = 0x0010 ;
  static const Unsigned16 NO_RTG                    = 0x0000 ;
  static const Unsigned16 PRESCALE                  = 0x0008 ;
  static const Unsigned16 NO_PRESCALE               = 0x0000 ;
  static const Unsigned16 EXTERNAL                  = 0x0004 ;
  static const Unsigned16 INTERNAL                  = 0x0000 ;
  static const Unsigned16 ALT                       = 0x0002 ;
  static const Unsigned16 NO_ALT                    = 0x0000 ;
  static const Unsigned16 CONT                      = 0x0001 ;
  static const Unsigned16 NO_CONT                   = 0x0000 ;

  static const Unsigned8  UPPER_EN                  = 0x80 ;
  static const Unsigned8  UPPER_B_RIU               = 0x10 ;





/*  Define Chip Select Registers */

  static const Unsigned16 CHIP_SELECT               = BASE + 0xA0 ;

  static const Unsigned16 UMCS_REG                  = CHIP_SELECT + 0x00 ;
  static const Unsigned16 LMCS_REG                  = CHIP_SELECT + 0x02 ;
  static const Unsigned16 PACS_REG                  = CHIP_SELECT + 0x04 ;
  static const Unsigned16 MMCS_REG                  = CHIP_SELECT + 0x06 ;
  static const Unsigned16 MPCS_REG                  = CHIP_SELECT + 0x08 ;



/*  Define DMA0 and DMA1 Registers and bits */

  static const Unsigned16 DMA_0                     = BASE + 0xC0 ;

  static const Unsigned16 DMA_0_SRC                 = DMA_0 + 0x00 ;
  static const Unsigned16 DMA_0_SRC_UP              = DMA_0 + 0x02 ;
  static const Unsigned16 DMA_0_DEST                = DMA_0 + 0x04 ;
  static const Unsigned16 DMA_0_DEST_UP             = DMA_0 + 0x06 ;
  static const Unsigned16 DMA_0_XFR_CNT             = DMA_0 + 0x08 ;
  static const Unsigned16 DMA_0_CONTROL             = DMA_0 + 0x0A ;

  static const Unsigned16 DMA_1                     = BASE + 0xD0 ;

  static const Unsigned16 DMA_1_SRC                 = DMA_1 + 0x00 ;
  static const Unsigned16 DMA_1_SRC_UP              = DMA_1 + 0x02 ;
  static const Unsigned16 DMA_1_DEST                = DMA_1 + 0x04 ;
  static const Unsigned16 DMA_1_DEST_UP             = DMA_1 + 0x06 ;
  static const Unsigned16 DMA_1_XFR_CNT             = DMA_1 + 0x08 ;
  static const Unsigned16 DMA_1_CONTROL             = DMA_1 + 0x0A ;

  static const Unsigned16 DEST_MEM                  = 0x8000 ;
  static const Unsigned16 DEST_I_O                  = 0x0000 ;
  static const Unsigned16 DEST_DEC                  = 0x4000 ;
  static const Unsigned16 DEST_INC                  = 0x2000 ;
  static const Unsigned16 DEST_CONST                = 0x6000 ;
  static const Unsigned16 SRC_MEM                   = 0x1000 ;
  static const Unsigned16 SRC_I_O                   = 0x0000 ;
  static const Unsigned16 SRC_DEC                   = 0x0800 ;
  static const Unsigned16 SRC_INC                   = 0x0400 ;
  static const Unsigned16 SRC_CONST                 = 0x0C00 ;
  static const Unsigned16 TC                        = 0x0200 ;
  static const Unsigned16 DMA_INT                   = 0x0100 ;
  static const Unsigned16 NO_DMA_INT                = 0x0000 ;
  static const Unsigned16 NO_SYNC                   = 0x0000 ;
  static const Unsigned16 DEST_SYNC                 = 0x0080 ;
  static const Unsigned16 SRC_SYNC                  = 0x0040 ;
  static const Unsigned16 HI_PRIORITY               = 0x0020 ;
  static const Unsigned16 LO_PRIORITY               = 0x0000 ;
  static const Unsigned16 TDRQ_EN                   = 0x0010 ;
  static const Unsigned16 TDRQ_DIS                  = 0x0000 ;
  static const Unsigned16 CHANGE                    = 0x0004 ;
  static const Unsigned16 NO_CHANGE                 = 0x0000 ;
  static const Unsigned16 DMA_START                 = 0x0002 ;
  static const Unsigned16 DMA_STOP                  = 0x0000 ;



/*  Define the Relocation Register bits */

  static const Unsigned16 RELOCATION_REG            = BASE + 0xFE ;
  static const Unsigned16 DEFLT_RELOC_REG           = 0xFF00 + 0xFE ;

  static const Unsigned16 SlAVE                     = 0x4000 ;
  static const Unsigned16 NOT_USED_BIT              = 0x2000 ;
  static const Unsigned16 MASTER                    = 0x0000 ;
  static const Unsigned16 MEMORY                    = 0x1000 ;
  static const Unsigned16 I_O                       = 0x0000 ;



/*  Define MIR register names and bits.  */


  static const Unsigned8 PROC_INTF_REG              = 0 ;

  static const Unsigned8 SIDA                       = 0x80 ;
  static const Unsigned8 ECMRMS                     = 0x40 ;
  static const Unsigned8 SPDREQ                     = 0x20 ;
  static const Unsigned8 PDC                        = 0x10 ;
  static const Unsigned8 SYSINT                     = 0x08 ;
  static const Unsigned8 INT2SYS                    = 0x04 ;
  static const Unsigned8 SYSINTM                    = 0x02 ;
  static const Unsigned8 PWDNDN                     = 0x01 ;

  static const Unsigned8 PWR_UP_CLK_TIME            = 1 ;

#define PUCT(x) ((x)<<4)

  static const Unsigned8 PWR_DOWN_LEN_CNT_L         = 2 ;
  static const Unsigned8 PWR_DOWN_LEN_CNT_M         = 3 ;
  static const Unsigned8 PWR_DOWN_LEN_CNT_U         = 4 ;

  static const Unsigned8 PERMAREST                  = 0x80 ;

  static const Unsigned8 FREE_CNT_L                 = 5 ;
  static const Unsigned8 FREE_CNT_M                 = 6 ;
  static const Unsigned8 FREE_CNT_U                 = 7 ;

  static const Unsigned8 FLASH_WAIT                 = 8 ;

  static const Unsigned8 HOSTALLOW                  = 0x08 ;
  static const Unsigned8 FLASHWAIT0                 = 0x00 ;
  static const Unsigned8 FLASHWAIT1                 = 0x01 ;
  static const Unsigned8 FLASHWAIT2                 = 0x02 ;
  static const Unsigned8 FLASHWAIT3                 = 0x03 ;

  static const Unsigned8 MISC                       = 9 ;

  static const Unsigned8 CLKGT20                    = 0x80 ;
  static const Unsigned8 NO_CLKGT20                 = 0x00 ;
  static const Unsigned8 Reserved                   = 0x40 ;
  static const Unsigned8 SRAMWAIT0                  = 0x00 ;
  static const Unsigned8 SRAMWAIT1                  = 0x10 ;
  static const Unsigned8 SRAMWAIT2                  = 0x20 ;
  static const Unsigned8 SRAMWAIT3                  = 0x30 ;
  static const Unsigned8 HOSTLONGWAIT               = 0x08 ;
  static const Unsigned8 INITDN                     = 0x04 ;
  static const Unsigned8 TCR_MASK                   = 0x02 ;
  static const Unsigned8 STSCHGD                    = 0x01 ;

/*  Define TIR register names and bits.  */


  static const Unsigned8 NETWORK_CONTROL            = 0x00 ;

  static const Unsigned8 LNK                        = 0x80 ;
  static const Unsigned8 ACT                        = 0x40 ;
  static const Unsigned8 SRES                       = 0x20 ;
  static const Unsigned8 SSTRB                      = 0x10 ;
  static const Unsigned8 RXP                        = 0x04 ;
  static const Unsigned8 LFPE                       = 0x02 ;
  static const Unsigned8 HFPE                       = 0x01 ;

  static const Unsigned8 NETWORK_STATUS             = 0x01 ;
  static const Unsigned8 SERIAL_DEVICE              = 0x02 ;
  static const Unsigned8 SDSEL1                     = 0x10 ;
  static const Unsigned8 SDSEL2                     = 0x20 ;
  static const Unsigned8 SDSEL3                     = 0x40 ;
  static const Unsigned8 FST_SER_PRT_CNTL           = 0x03 ;
  static const Unsigned8 INT_REG_1                  = 0x04 ;
  static const Unsigned8 INT_UNMASK_1               = 0x06 ;

  static const Unsigned8 CHBSYC                     = 0x80 ;
  static const Unsigned8 ANTSW                      = 0x40 ;
  static const Unsigned8 MOREINT                    = 0x20 ;
  static const Unsigned8 TXCNT                      = 0x10 ;
  static const Unsigned8 TXDONE                     = 0x08 ;
  static const Unsigned8 CRCS                       = 0x04 ;
  static const Unsigned8 SDSNT                      = 0x02 ;
  static const Unsigned8 TXFBN                      = 0x01 ;

  static const Unsigned8 INT_REG_2                  = 0x05 ;
  static const Unsigned8 INT_UNMASK_2               = 0x07 ;

  static const Unsigned8 RXCNT                      = 0x80 ;
  static const Unsigned8 CRC8G                      = 0x40 ;
  static const Unsigned8 CRC32G                     = 0x20 ;
  static const Unsigned8 RXFOR                      = 0x10 ;
  static const Unsigned8 RXFBA                      = 0x08 ;
  static const Unsigned8 SDF                        = 0x04 ;
  static const Unsigned8 BCF                        = 0x02 ;
  static const Unsigned8 ALOKI                      = 0x01 ;

  static const Unsigned8 TXMT_CONTROL               = 0x08 ;

  static const Unsigned8 TXRES                      = 0x80 ;
  static const Unsigned8 TXFR                       = 0x40 ;
  static const Unsigned8 CRC32                      = 0x04 ;
  static const Unsigned8 TXS                        = 0x01 ;

  static const Unsigned8 TXMT_STATUS                = 0x09 ;

  static const Unsigned8 TXBSY                      = 0x01 ;

  static const Unsigned8 TX_FIFO_DATA               = 0x0a ;
  static const Unsigned8 TXMT_SEQ_CNTL              = 0x0b ;

  static const Unsigned8 RXCD                       = 0x80 ;
  static const Unsigned8 USER6D                     = 0x40 ;
  static const Unsigned8 USER5D                     = 0x20 ;
  static const Unsigned8 LLOCKE                     = 0x10 ;
  static const Unsigned8 RCEN                       = 0x08 ;
  static const Unsigned8 TXMOD                      = 0x04 ;
  static const Unsigned8 TXPE                       = 0x02 ;
  static const Unsigned8 TXCMD                      = 0x01 ;

  static const Unsigned8 BYTE_COUNT_LSB             = 0x0c ;
  static const Unsigned8 BYTE_COUNT_MSB             = 0x0d ;
  static const Unsigned8 BYTE_CNT_LMT_LSB           = 0x0e ;
  static const Unsigned8 BYTE_CNT_LMT_MSB           = 0x0f ;
  static const Unsigned8 RCVR_CONTROL               = 0x10 ;

  static const Unsigned8 RXRES                      = 0x80 ;
  static const Unsigned8 RXFR                       = 0x40 ;
  static const Unsigned8 RXS                        = 0x01 ;

  static const Unsigned8 RCVR_STATUS                = 0x11 ;

  static const Unsigned8 CRC32_GOOD                 = 0x80 ;
  static const Unsigned8 RXBSY                      = 0x01 ;

  static const Unsigned8 RX_FIFO_DATA               = 0x12 ;
  static const Unsigned8 ANTENNA_SLOT               = 0x13 ;
  static const Unsigned8 CRC32_CORRECT_LSB          = 0x14 ;
  static const Unsigned8 CRC32_CORRECT_MSB          = 0x15 ;
  static const Unsigned8 CRC8_CORRECT_LSB           = 0x16 ;
  static const Unsigned8 CRC8_CORRECT_MSB           = 0x17 ;
  static const Unsigned8 CONFIG_INDEX               = 0x18 ;
  static const Unsigned8 CONFIG_DATA_PORT           = 0x19 ;
  static const Unsigned8 ANT_DVRSTY_A_D             = 0x1a ;

  static const Unsigned8 CHBSY                      = 0x80 ;
    static const Unsigned8 ANTLOK                   = 0x40 ;

  static const Unsigned8 SAR                        = 0x1b ;
  static const Unsigned8 RSSI_LOW_LMT               = 0x1c ;
  static const Unsigned8 USER_PIN_DATA              = 0x1d ;

  static const Unsigned8 USER7D                     = 0x80 ;
  static const Unsigned8 USER4D                     = 0x10 ;
  static const Unsigned8 USER3D                     = 0x08 ;
  static const Unsigned8 USER2D                     = 0x04 ;
  static const Unsigned8 USER1D                     = 0x02 ;
  static const Unsigned8 USER0D                     = 0x01 ;

  static const Unsigned8 DUMMY_REG                  = 0x1e ;
  static const Unsigned8 TEST_REG                   = 0x1f ;


/*  Define TCR register names and bits.  */


  static const Unsigned8 NETWORK_CONFIGURATION      = 0x00 ;

#define DRB(x) ((x)<<5)
#define HDB(x) ((x)<<2)
#define SD(x)  ((x))

  static const Unsigned8 TRANSMIT_CONFIGURATION     = 0x01 ;

  static const Unsigned8 TXDC_1                     = 0x02 ;
  static const Unsigned8 TXDC_0                     = 0x01 ;

  static const Unsigned8 CLOCK_RECOVERY             = 0x02 ;
  static const Unsigned8 ECLK                       = 0x20 ;

#define CLKP(x)  ((x))

  static const Unsigned8 RECEIVE_CONFIGURATION      = 0x03 ;

  static const Unsigned8 LOOPB                      = 0x80 ;
#define PFL(x) ((x))

  static const Unsigned8 ANTENNA_DIVERSITY_TIMER    = 0x04 ;

  static const Unsigned8 ANTEN                      = 0x80 ;
#define ADT(x) ((x))

  static const Unsigned8 TX_RAMP_UP_TIMING          = 0x05 ;

#define TGAP1(x) ((x)<<4)
#define TGAP2(x) ((x))

  static const Unsigned8 TX_RAMP_DOWN_TIMING        = 0x06 ;

#define TGAP3(x) ((x)<<4)
#define TGAP4(x) ((x))

  static const Unsigned8 PIN_DATA_A                 = 0x07 ;
  static const Unsigned8 TXCMDT                     = 0x04 ;

  static const Unsigned8 START_DELIMITER_LSB        = 0x08 ;
  static const Unsigned8 START_DELIMITER_CSB        = 0x09 ;
  static const Unsigned8 START_DELIMITER_MSB        = 0x0a ;
  static const Unsigned8 INTERRUPT_REGISTER_3       = 0x0b ;
  static const Unsigned8 INTERRUPT_UNMASK_REG_3     = 0x0c ;
  static const Unsigned8 PIN_CONFIGURATION_A        = 0x0d ;
  static const Unsigned8 PIN_CONFIGURATION_B        = 0x0e ;
  static const Unsigned8 PIN_CONFIGURATION_C        = 0x0f ;
  static const Unsigned8 BAUD_DETECT_START          = 0x10 ;

#define BDS(x) ((x))

  static const Unsigned8 BAUD_DETECT_LOWER_LIMIT    = 0x11 ;

#define BDLLT(x)  ((x))

  static const Unsigned8 BAUD_DETECT_UPPER_LIMIT    = 0x12 ;

#define BDULT(x) ((x))

  static const Unsigned8 BAUD_DTCT_ACCEPT_CNT_CS    = 0x13 ;

#define BDCS(x) ((x))

  static const Unsigned8 BAUD_DTCT_ACCEPT_CNT_SD    = 0x14 ;

#define BDSD(x) ((x))

  static const Unsigned8 BAUD_DETECT_RATIO          = 0x15 ;

#define BDRN(x) ((x))

  static const Unsigned8 BAUD_DETECT_ACCEPT_COUNT   = 0x16 ;
  static const Unsigned8 BAUD_DETECT_FAIL_COUNT     = 0x17 ;
  static const Unsigned8 RSSI_SAMPLE_START          = 0x18 ;

#define SS(x) ((x))

  static const Unsigned8 RSSI_CONFIGURATION         = 0x19 ;

  static const Unsigned8 UXA2DST                    = 0x80 ;
  static const Unsigned8 ENEXT                      = 0x40 ;
  static const Unsigned8 ENSAR                      = 0x20 ;
#define A2DT(x) ((x))

  static const Unsigned8 RESERVED_TCR               = 0x1a ;
  static const Unsigned8 TIP_LED_SCRAMBLE           = 0x1b ;
  static const Unsigned8 CCA_CONFIGURATION          = 0x1c ;

  static const Unsigned8 ENXSDF                     = 0x40 ;
  static const Unsigned8 ENXCHBSY                   = 0x20 ;
  static const Unsigned8 RUPD                       = 0x10 ;
  static const Unsigned8 STPEN                      = 0x08 ;
  static const Unsigned8 UBDSD                      = 0x04 ;
  static const Unsigned8 UBDCS                      = 0x02 ;
  static const Unsigned8 URSSI                      = 0x01 ;

  static const Unsigned8 RESERVED_TCR_2             = 0x1d ;
  static const Unsigned8 PIN_FUNCTION_DATA_RATE     = 0x1e ;

  static const Unsigned8 TXCIN                      = 0x08 ;
#define DR(x)  ((x))

  static const Unsigned8 DEVICE_REVISION            = 0x1f ;

#endif /* REGISTERS_HPP */


