/* am930mod.c: ISA module for PRISM/AM79C930 card from Harris
*	--------------------------------------------------------------------
*
*   Linux WLAN 
*
*   The contents of this file are subject to the Mozilla Public
*   License Version 1.0 (the "License"); you may not use this file
*   except in compliance with the License. You may obtain a copy of
*   the License at http://www.mozilla.org/MPL/
*
*   Software distributed under the License is distributed on an "AS
*   IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
*   implied. See the License for the specific language governing
*   rights and limitations under the License.
*
*   The initial developer of the original code is Mark S. Mathews
*   <mark@absoval.com>.  Portions created by Mark S. Mathews
*   are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
*   
*	--------------------------------------------------------------------
*
*	The author may be reached as mark@absoval.com, or C/O AbsoluteValue
*	Software Inc., P.O. Box 941149, Maitland, FL, 32794-1149
*
*	Thanks to David Hinds, Donald Becker, and the rest of the Linux
*	developers worldwide for making all of this possible.
*
*	--------------------------------------------------------------------
*
*	This file contains the entry points/cleanup routines for modules and
*	ISA drivers.  Additionally, all "driver global" variables are
*	defined here.
*
*	MSM 02/13/97
*/

/* PCMCIA headers generated during PCMCIA package installation */
/* These are required for compilation only, PCMCIA is not required
 * on the target system when using the resulting module.
 */
#include <pcmcia/config.h>
#include <pcmcia/k_compat.h>

/* Module related headers, non-module drivers should not include */

#include <linux/module.h>
#include <linux/version.h>


/* Standard driver includes */
#include <assert.h>
#include <linux/kernel.h>
#include <linux/types.h>
#include <linux/sched.h>
#include <linux/fcntl.h>
#include <linux/interrupt.h>
#include <linux/ptrace.h>
#include <linux/ioport.h>
#include <linux/in.h>
#include <linux/malloc.h>
#include <linux/string.h>
#include <linux/timer.h>
#include <linux/kernel_stat.h>
#include <linux/delay.h>

#include <asm/system.h>
#include <asm/bitops.h>
#include <asm/io.h>

#include <linux/errno.h>

/* Ethernet and network includes */
#include <linux/if_ether.h>
#include <linux/netdevice.h>
#include <linux/etherdevice.h>
#include <linux/skbuff.h>
#include <linux/if_arp.h>

/* Card and Driver services includes */
#include <pcmcia/version.h>
#include <pcmcia/cs_types.h>
#include <pcmcia/cs.h>
#include <pcmcia/cistpl.h>
#include <pcmcia/ds.h>
#include <pcmcia/mem_op.h>

/*================================================================*/
/* Local Includes */

#include <wlan/version.h>
#include <wlan/p80211hdr.h>
#include "am930llc.h"
#include "am930mac.h"


/*================================================================*/
/* Local macros */

#if (LINUX_VERSION_CODE < VERSION(2,2,0))
#define ioremap_nocache ioremap
#endif

/*================================================================*/
/* Local statics */

static char *version = "am930mod.c 0.1.3 1998/10/20";

/*================================================================*/
/* "Driver global" definitions */

//UINT32	dbmask = DBMASK; 		/* Mask var to control debug messages */

int		am930_use_mmio=0;		/* use memory mapped i/o or not */
MODULE_PARM( am930_use_mmio, "i");

int		am930_iodelay=0;		/* udelay between memory or i/o reads */
MODULE_PARM( am930_iodelay, "i");

int		am930_iobase=0;			/* IO address */
MODULE_PARM( am930_iobase, "i");

int		am930_irq=0;			/* IRQ */
MODULE_PARM( am930_irq, "i");

int		am930_membase=0;		/* Memory base */
MODULE_PARM( am930_membase, "i");

int		am930_isap=0;			/* are we an AP? */
MODULE_PARM( am930_isap, "i");

int		wlan_debug=0;			/* Debug output level, declared in */
MODULE_PARM( wlan_debug, "i");	                /* wlan_compat.h */


/*================================================================*/
/* Local functions */
int	init_module(void);
void	cleanup_module(void);

dev_link_t *am930_drvr_attach(void);
void        am930_drvr_detach(dev_link_t *);

dev_link_t tricky_di;
dev_node_t tricky_dev;
//am930mac_t mac;

/*
 * am930mod_interrupt --
 *
 */

static void
am930mod_interrupt IRQ(int irq, void *dev_id, struct pt_regs *regs)
{
  DBFENTER;

  am930mac_ISR (tricky_di.priv);

  DBFEXIT;
}

/*----------------------------------------------------------------
*	init_module
*
*	Module initialization routine. For an ISA device this has to
*	setup a dev_link structure, fill it in with information provided
*	and request the IRQ.
*
*	returns: zero on success, non-zero on failure.
----------------------------------------------------------------*/
int init_module(void)
{
	DBFENTER;

	printk( KERN_DEBUG"init_module:%s\n", version);

	printk(KERN_INFO "Linux WLAN " WLAN_RELEASE "\n");

	memset (&tricky_di, 0, sizeof (dev_link_t));
	memset (&tricky_dev, 0, sizeof (dev_node_t));
	tricky_di.state = DEV_PRESENT | DEV_CONFIG;
	tricky_di.dev = &tricky_dev;
	tricky_di.irq.AssignedIRQ = am930_irq;
	tricky_di.io.BasePort1 = am930_iobase;
	
	request_irq (am930_irq, am930mod_interrupt, 0,
		     tricky_di.dev->dev_name, NULL);
	am930_membase = (UINT32)ioremap_nocache (am930_membase, 0x8000);
	am930mac_construct (&tricky_di, am930_membase);

	DBFEXIT;
	return 0;
}


/*----------------------------------------------------------------
*	cleanup_module
*
*	This is the destructor for the am930_drvr object.
*
*	Standard module unload callback function. For ISA, that
*	means that the IRQ must be release.
*
*	returns: nothing
----------------------------------------------------------------*/
void cleanup_module(void)
{
        DBFENTER;

	am930mac_destruct (tricky_di. priv);

	/* TODO: handle destruction cleanly, call subobject destructors
	         after testing subobject pointers for NULL */

	free_irq(am930_irq, NULL);

	DBFEXIT;
	return;
}

